@@ -1,31 +1,5 @@
 #   Copyright (c) 2017, Xilinx, Inc.
-#   All rights reserved.
-#
-#   Redistribution and use in source and binary forms, with or without
-#   modification, are permitted provided that the following conditions are met:
-#
-#   1.  Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#   2.  Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#   3.  Neither the name of the copyright holder nor the names of its
-#       contributors may be used to endorse or promote products derived from
-#       this software without specific prior written permission.
-#
-#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-#   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-#   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-#   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-#   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-#   OR BUSINESS INTERRUPTION). HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-#   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-#   OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-#   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#   SPDX-License-Identifier: BSD-3-Clause
 
 
 import asyncio
@@ -36,9 +10,6 @@ from .ps import CPU_ARCH, ZU_ARCH, ZYNQ_ARCH
 from .mmio import MMIO
 from .uio import get_uio_device, UioController
 
-__author__ = "Peter Ogden"
-__copyright__ = "Copyright 2017, Xilinx"
-__email__ = "pynq_support@xilinx.com"
 
 
 def get_uio_irq(irq):
@@ -98,8 +69,7 @@ class Interrupt(object):
         self.event = asyncio.Event()
         self.waiting = False
 
-    @asyncio.coroutine
-    def wait(self):
+    async def wait(self):
         """Wait for the interrupt to be active
 
         May raise an exception if the Overlay has been changed since
@@ -112,7 +82,7 @@ class Interrupt(object):
             self.event.clear()
             parent.add_event(self.event, self.number)
             self.waiting = True
-        yield from self.event.wait()
+        await self.event.wait()
         self.waiting = False
 
 
@@ -261,3 +231,5 @@ class _InterruptController(object):
         self.event_number += 1
         # Enable global interrupt
         self.mmio.write(0x1C, 0x00000003)
+
+
