@@ -1,35 +1,13 @@
 /******************************************************************************
-*
-* Copyright (C) 2002 - 2016 Xilinx, Inc.  All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (C) 2002 - 2021 Xilinx, Inc.  All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 *
 * @file xiic.h
-* @addtogroup iic_v3_4
+* @addtogroup Overview
 * @{
 * @details
 *
@@ -124,7 +102,7 @@
 * Addresses are represented as hex values with no adjustment for the data
 * direction bit as the software manages address bit placement. This is
 * especially important as the bit placement is not handled the same depending
-* on which options are used such as repeated start and 7 vs 10 bit addessing.
+* on which options are used such as repeated start and 7 vs 10 bit addressing.
 *
 * <b>Data Rates</b>
 *
@@ -162,7 +140,7 @@
 *   - Addressed As Slave
 *   - Not Addressed As Slave
 *
-* The following interrupts are not passed directly to the application thru the
+* The following interrupts are not passed directly to the application through the
 * status callback.  These are only used internally for the driver processing
 * and may result in the receive and send handlers being called to indicate
 * completion of an operation.  The following interrupts are data related
@@ -192,7 +170,7 @@
 * <b>Not Addressed As Slave Interrupt</b>
 *
 * The Not Addressed As Slave interrupt is not passed directly to the
-* application thru the status callback.  It is used to determine the end of
+* application through the status callback.  It is used to determine the end of
 * a message being received by a slave when there was no stop condition
 * (repeated start).  It will cause the receive handler to be called to
 * indicate completion of the operation.
@@ -261,7 +239,7 @@
 *		      using Addressed As Slave (AAS) bit when addressed as
 *		      slave in XIic_Send for CR565373.
 * 2.03a rkv  01/25/11 Updated in NAAS interrupt handler to support data
-*		      recieved less than FIFO size prior to NAAS interrupt.
+*		      received less than FIFO size prior to NAAS interrupt.
 *		      Fixed for CR590212.
 * 2.04a sdm  07/22/11 Added IsSlaveSetAckOff flag to the instance structure.
 *		      This flag is set when the Slave has set the Ack Off in the
