@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright (C) 2010 - 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (C) 2010 - 2021 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 ******************************************************************************/
 
@@ -7,10 +7,10 @@
 /**
 *
 * @file xiicps_master.c
-* @addtogroup iicps_v3_12
+* @addtogroup Overview
 * @{
 *
-* Handles master mode transfers.
+* The xiicps_master.c file handles master mode transfers.
 *
 * <pre> MODIFICATION HISTORY:
 *
@@ -48,6 +48,9 @@
 * 3.11  sd  02/06/20 Added clocking support.
 * 3.11  rna 02/12/20 Moved static data transfer functions to xiicps_xfer.c file
 *	    02/18/20 Modified latest code for MISRA-C:2012 Compliance.
+* 3.13  rna 11/24/20 Added timeout to XIicPs_MasterSendPolled function.
+*	rna 12/17/20 Clear hold bit at correct time in Rx path of ISR
+*	rna 05/24/21 Fix Misra c violations
 * </pre>
 *
 ******************************************************************************/
@@ -56,12 +59,14 @@
 
 #include "xiicps.h"
 #include "xiicps_xfer.h"
+#include "sleep.h"
 
 /************************** Constant Definitions *****************************/
 
 /**************************** Type Definitions *******************************/
 
 /***************** Macros (Inline Functions) Definitions *********************/
+#define TX_MAX_LOOPCNT 1000000U	/**< Used to wait in polled function */
 
 /************************** Function Prototypes ******************************/
 
@@ -88,7 +93,7 @@
 void XIicPs_MasterSend(XIicPs *InstancePtr, u8 *MsgPtr, s32 ByteCount,
 		 u16 SlaveAddr)
 {
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 	u32 Platform = XGetPlatform_Info();
 
 	/*
@@ -150,7 +155,7 @@ void XIicPs_MasterSend(XIicPs *InstancePtr, u8 *MsgPtr, s32 ByteCount,
 	{
 		XIicPs_WriteReg(BaseAddr, XIICPS_CR_OFFSET,
 				XIicPs_ReadReg(BaseAddr, (u32)XIICPS_CR_OFFSET) &
-				(u32)(~XIICPS_CR_HOLD_MASK));
+				(~(u32)XIICPS_CR_HOLD_MASK));
 	}
 
 }
@@ -176,7 +181,7 @@ void XIicPs_MasterSend(XIicPs *InstancePtr, u8 *MsgPtr, s32 ByteCount,
 void XIicPs_MasterRecv(XIicPs *InstancePtr, u8 *MsgPtr, s32 ByteCount,
 		 u16 SlaveAddr)
 {
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 
 	/*
 	 * Assert validates the input arguments.
@@ -235,7 +240,7 @@ void XIicPs_MasterRecv(XIicPs *InstancePtr, u8 *MsgPtr, s32 ByteCount,
 	XIicPs_EnableInterrupts(BaseAddr,
 		(u32)XIICPS_IXR_NACK_MASK | (u32)XIICPS_IXR_DATA_MASK |
 		(u32)XIICPS_IXR_RX_OVR_MASK | (u32)XIICPS_IXR_COMP_MASK |
-		(u32)XIICPS_IXR_ARB_LOST_MASK | XIICPS_IXR_TO_MASK);
+		(u32)XIICPS_IXR_ARB_LOST_MASK | (u32)XIICPS_IXR_TO_MASK);
 	/*
 	 * Do the address transfer to signal the slave.
 	 */
@@ -272,9 +277,10 @@ s32 XIicPs_MasterSendPolled(XIicPs *InstancePtr, u8 *MsgPtr,
 {
 	u32 IntrStatusReg;
 	u32 StatusReg;
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 	u32 Intrs;
-	s32 Status;
+	s32 Status = (s32)XST_FAILURE;
+	u32 timeout = 0;
 	_Bool Value;
 
 	/*
@@ -364,6 +370,17 @@ s32 XIicPs_MasterSendPolled(XIicPs *InstancePtr, u8 *MsgPtr,
 		 * If there is an error, tell the caller.
 		 */
 		if ((IntrStatusReg & Intrs) != 0U) {
+			if ((IntrStatusReg & XIICPS_IXR_ARB_LOST_MASK) != 0U) {
+				Status = (s32) XST_IIC_ARB_LOST;
+			}
+			break;
+		}
+		/*
+		 * Timeout if stuck for more than 1 second
+		 */
+		usleep(1);
+		timeout++;
+		if (timeout == TX_MAX_LOOPCNT) {
 			break;
 		}
 	}
@@ -374,14 +391,9 @@ s32 XIicPs_MasterSendPolled(XIicPs *InstancePtr, u8 *MsgPtr,
 						(~XIICPS_CR_HOLD_MASK));
 	}
 
-	if ((IntrStatusReg & Intrs) != 0U) {
-		if ((IntrStatusReg & XIICPS_IXR_ARB_LOST_MASK) != 0U) {
-			Status = (s32) XST_IIC_ARB_LOST;
-		} else {
-			Status = (s32)XST_FAILURE;
-		}
-	} else {
-			Status = (s32)XST_SUCCESS;
+	/* Set the Status for XST_SUCCESS */
+	if (((IntrStatusReg & Intrs) == 0U) && (timeout != TX_MAX_LOOPCNT)) {
+		Status = (s32)XST_SUCCESS;
 	}
 
 	return Status;
@@ -416,7 +428,7 @@ s32 XIicPs_MasterRecvPolled(XIicPs *InstancePtr, u8 *MsgPtr,
 {
 	u32 IntrStatusReg;
 	u32 Intrs;
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 	s32 Result;
 	s32 IsHold;
 	s32 UpdateTxSize = 0;
@@ -429,7 +441,7 @@ s32 XIicPs_MasterRecvPolled(XIicPs *InstancePtr, u8 *MsgPtr,
 	Xil_AssertNonvoid(InstancePtr != NULL);
 	Xil_AssertNonvoid(MsgPtr != NULL);
 	Xil_AssertNonvoid(InstancePtr->IsReady == (u32)XIL_COMPONENT_IS_READY);
-	Xil_AssertNonvoid(XIICPS_ADDR_MASK >= SlaveAddr);
+	Xil_AssertNonvoid((u16)XIICPS_ADDR_MASK >= SlaveAddr);
 
 	BaseAddr = InstancePtr->Config.BaseAddress;
 	InstancePtr->RecvBufferPtr = MsgPtr;
@@ -608,7 +620,7 @@ s32 XIicPs_MasterRecvPolled(XIicPs *InstancePtr, u8 *MsgPtr,
 ****************************************************************************/
 void XIicPs_EnableSlaveMonitor(XIicPs *InstancePtr, u16 SlaveAddr)
 {
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 	u32 ConfigReg;
 
 	Xil_AssertVoid(InstancePtr != NULL);
@@ -631,13 +643,13 @@ void XIicPs_EnableSlaveMonitor(XIicPs *InstancePtr, u16 SlaveAddr)
 	ConfigReg = XIicPs_ReadReg(BaseAddr, (u32)XIICPS_CR_OFFSET);
 	ConfigReg |= (u32)XIICPS_CR_MS_MASK | (u32)XIICPS_CR_CLR_FIFO_MASK |
 			(u32)XIICPS_CR_SLVMON_MASK;
-	ConfigReg &= (u32)(~XIICPS_CR_RD_WR_MASK);
+	ConfigReg &= ~((u32)XIICPS_CR_RD_WR_MASK);
 
 	/*
 	 * Check if 10 bit address option is set.
 	 */
 	if (InstancePtr->Is10BitAddr == 1) {
-		ConfigReg &= (u32)(~XIICPS_CR_NEA_MASK);
+		ConfigReg &= ~((u32)XIICPS_CR_NEA_MASK);
 	} else {
 		ConfigReg |= (u32)(XIICPS_CR_NEA_MASK);
 	}
@@ -677,7 +689,7 @@ void XIicPs_EnableSlaveMonitor(XIicPs *InstancePtr, u16 SlaveAddr)
 ****************************************************************************/
 void XIicPs_DisableSlaveMonitor(XIicPs *InstancePtr)
 {
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 	u32 ControlReg;
 
 	Xil_AssertVoid(InstancePtr != NULL);
@@ -742,7 +754,6 @@ void XIicPs_DisableSlaveMonitor(XIicPs *InstancePtr)
 *
 * Completion events and errors are signaled to upper layer for proper handling.
 *
-* <pre>
 * The interrupts that are handled are:
 * - DATA
 *	This case is handled only for master receive data.
@@ -768,8 +779,6 @@ void XIicPs_DisableSlaveMonitor(XIicPs *InstancePtr)
 *	These interrupts are marked as error. This is signalled to the upper
 *	layer by calling the callback handler.
 *
-* </pre>
-*
 * @param	InstancePtr is a pointer to the XIicPs instance.
 *
 * @return	None.
@@ -781,7 +790,7 @@ void XIicPs_MasterInterruptHandler(XIicPs *InstancePtr)
 {
 	u32 IntrStatusReg;
 	u32 StatusEvent = 0U;
-	u32 BaseAddr;
+	UINTPTR BaseAddr;
 	u16 SlaveAddr;
 	s32 ByteCnt;
 	s32 IsHold;
@@ -843,18 +852,21 @@ void XIicPs_MasterInterruptHandler(XIicPs *InstancePtr)
 		 (0U != (IntrStatusReg & (u32)XIICPS_IXR_COMP_MASK)))){
 
 		while ((XIicPs_RxDataValid(InstancePtr)) != 0U) {
-			if ((InstancePtr->RecvByteCount <
-				XIICPS_DATA_INTR_DEPTH)  && (IsHold != 0)  &&
-				(InstancePtr->IsRepeatedStart == 0) &&
-				(InstancePtr->UpdateTxSize == 0)) {
+
+			XIicPs_RecvByte(InstancePtr);
+			ByteCnt--;
+
+			/* Clear hold bit when not required */
+			if ((InstancePtr->RecvByteCount <=
+					XIICPS_DATA_INTR_DEPTH) && (IsHold != 0)
+					&& (InstancePtr->IsRepeatedStart == 0)
+					&& (InstancePtr->UpdateTxSize == 0)) {
 				IsHold = 0;
 				XIicPs_WriteReg(BaseAddr, XIICPS_CR_OFFSET,
 						XIicPs_ReadReg(BaseAddr,
 						XIICPS_CR_OFFSET) &
 						(~XIICPS_CR_HOLD_MASK));
 			}
-			XIicPs_RecvByte(InstancePtr);
-			ByteCnt--;
 
 			if (Platform == (u32)XPLAT_ZYNQ) {
 			    if ((InstancePtr->UpdateTxSize != 0) &&
