@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright (C) 2010 - 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (C) 2010 - 2021 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 ******************************************************************************/
 
@@ -7,7 +7,7 @@
 /**
 *
 * @file xscugic_hw.c
-* @addtogroup scugic_v4_3
+* @addtogroup scugic_v4_7
 * @{
 *
 * This file contains low-level driver functions that can be used to access the
@@ -67,6 +67,20 @@
 *                     fixes CR#1033401.
 * 4.3   mus  05/11/20 Added assert checks in XScuGic_EnableIntr and
 *                     XScuGic_DisableIntr API. It fixes CR#1063034.
+* 4.5   asa  03/07/21 Added spinlock protection for critical sections in the
+*                     code. The sections are critical when applications
+*                     running on separate CPUs (R5s or A9s) try to update
+*                     the same register. The spinlock mechanism used here
+*                     used exclusive load and store instructions. To ensure
+*                     that legacy behavior is not broken, unless someone
+*                     enables spinlocks explicitely in their applications
+*                     the existing flow will remain unchanged. On how to
+*                     enable spinlocks, please refer to the documentations
+*                     at: lib/bsp/standalone/src/arm/common/gcc/xil_spinlock.c
+* 4.6	sk   08/05/21 Fix Scugic Misrac violations.
+* 4.7	sk   09/14/21 Fix gcc compiler warnings for A72 processor.
+* 4.7	sk   10/13/21 Update APIs to perform interrupt mapping/unmapping only
+* 		      when (Int_Id >= XSCUGIC_SPI_INT_ID_START).
 * </pre>
 *
 ******************************************************************************/
@@ -87,15 +101,14 @@
 
 /************************** Function Prototypes ******************************/
 
-static void DistInit(XScuGic_Config *Config);
+static void DistInit(const XScuGic_Config *Config);
 #if !defined (GICv3)
-static void CPUInit(XScuGic_Config *Config);
+static void CPUInit(const XScuGic_Config *Config);
 #endif
 static XScuGic_Config *LookupConfigByBaseAddress(u32 CpuBaseAddress);
 
 /************************** Variable Definitions *****************************/
 
-extern XScuGic_Config XScuGic_ConfigTable[XPAR_XSCUGIC_NUM_INSTANCES];
 
 /*****************************************************************************/
 /**
@@ -115,15 +128,15 @@ extern XScuGic_Config XScuGic_ConfigTable[XPAR_XSCUGIC_NUM_INSTANCES];
 * @note		None.
 *
 ******************************************************************************/
-static void DistInit(XScuGic_Config *Config)
+static void DistInit(const XScuGic_Config *Config)
 {
 	u32 Int_Id;
 
-#if USE_AMP == 1
+#if (defined (USE_AMP) && (USE_AMP==1))
 	#warning "Building GIC for AMP"
 
 	/*
-	 * The distrubutor should not be initialized by FreeRTOS in the case of
+	 * The distributor should not be initialized by FreeRTOS in the case of
 	 * AMP -- it is assumed that Linux is the master of this device in that
 	 * case.
 	 */
@@ -253,7 +266,7 @@ static void DistInit(XScuGic_Config *Config)
 * @note		None.
 *
 ******************************************************************************/
-static void CPUInit(XScuGic_Config *Config)
+static void CPUInit(const XScuGic_Config *Config)
 {
 	/*
 	 * Program the priority mask of the CPU using the Priority mask
@@ -372,8 +385,8 @@ void XScuGic_DeviceInterruptHandler(void *DeviceId)
 	 * multiple processors.
 	 */
 	/*
-	 * If pre-eption is required:
-	 * Re-enable pre-emption by setting the CPSR I bit for non-secure ,
+	 * If preemption is required:
+	 * Re-enable preemption by setting the CPSR I bit for non-secure ,
 	 * interrupts or the F bit for secure interrupts
 	 */
 
@@ -533,6 +546,15 @@ void XScuGic_SetPriTrigTypeByDistAddr(u32 DistBaseAddress, u32 Int_Id,
 		return;
 	}
 #endif
+
+	/*
+	 * Call spinlock to protect multiple applications running at separate
+	 * CPUs to write to the same register. This macro also ensures that
+	 * the spinlock mechanism is used only if spinlock is enabled by
+	 * user.
+	 */
+	XIL_SPINLOCK();
+
 	/*
 	 * Determine the register to write to using the Int_Id.
 	 */
@@ -550,7 +572,7 @@ void XScuGic_SetPriTrigTypeByDistAddr(u32 DistBaseAddress, u32 Int_Id,
 	 * Shift and Mask the correct bits for the priority and trigger in the
 	 * register
 	 */
-	RegValue &= ~(XSCUGIC_PRIORITY_MASK << ((Int_Id%4U)*8U));
+	RegValue &= ~((u32)XSCUGIC_PRIORITY_MASK << ((Int_Id%4U)*8U));
 	RegValue |= (u32)LocalPriority << ((Int_Id%4U)*8U);
 
 	/*
@@ -568,7 +590,7 @@ void XScuGic_SetPriTrigTypeByDistAddr(u32 DistBaseAddress, u32 Int_Id,
 	 * Shift and Mask the correct bits for the priority and trigger in the
 	 * register
 	 */
-	RegValue &= ~(XSCUGIC_INT_CFG_MASK << ((Int_Id%16U)*2U));
+	RegValue &= ~((u32)XSCUGIC_INT_CFG_MASK << ((Int_Id%16U)*2U));
 	RegValue |= (u32)Trigger << ((Int_Id%16U)*2U);
 
 	/*
@@ -576,6 +598,12 @@ void XScuGic_SetPriTrigTypeByDistAddr(u32 DistBaseAddress, u32 Int_Id,
 	 */
 	XScuGic_WriteReg(DistBaseAddress, XSCUGIC_INT_CFG_OFFSET_CALC(Int_Id),
 				RegValue);
+
+	/*
+	 * Release the lock previously taken. This macro ensures that the lock
+	 * is given only if spinlock mechanism is enabled by the user.
+	 */
+	XIL_SPINUNLOCK();
 }
 
 /****************************************************************************/
@@ -652,33 +680,47 @@ void XScuGic_InterruptMapFromCpuByDistAddr(u32 DistBaseAddress,
 	u32 RegValue;
 #if !defined (GICv3)
 	u32 Offset;
+	u8 Cpu_CoreId;
 #endif
 
 	Xil_AssertVoid(Int_Id < XSCUGIC_MAX_NUM_INTR_INPUTS);
+
+if (Int_Id >= XSCUGIC_SPI_INT_ID_START) {
 #if defined (GICv3)
 	u32 Temp;
-	if (Int_Id >= 32) {
-		Temp = Int_Id - 32;
-		RegValue = XScuGic_ReadReg(DistBaseAddress,
-				XSCUGIC_IROUTER_OFFSET_CALC(Temp));
-		RegValue |= (Cpu_Id);
-		XScuGic_WriteReg(DistBaseAddress, XSCUGIC_IROUTER_OFFSET_CALC(Temp),
-			RegValue);
-	}
+	Temp = Int_Id - 32;
+	RegValue = XScuGic_ReadReg(DistBaseAddress,
+			XSCUGIC_IROUTER_OFFSET_CALC(Temp));
+	RegValue |= (Cpu_Id);
+	XScuGic_WriteReg(DistBaseAddress, XSCUGIC_IROUTER_OFFSET_CALC(Temp),
+		RegValue);
 #else
+	/*
+	 * Call spinlock to protect multiple applications running at separate
+	 * CPUs to write to the same register. This macro also ensures that
+	 * the spinlock mechanism is used only if spinlock is enabled by
+	 * user.
+	 */
+	XIL_SPINLOCK();
 	RegValue = XScuGic_ReadReg(DistBaseAddress,
 					XSCUGIC_SPI_TARGET_OFFSET_CALC(Int_Id));
 
 	Offset = (Int_Id & 0x3U);
-	Cpu_Id = (0x1U << Cpu_Id);
+	Cpu_CoreId = (0x1U << Cpu_Id);
 
-	RegValue |= (Cpu_Id) << (Offset*8U);
+	RegValue |= (u32)(Cpu_CoreId) << (Offset*8U);
 
 	XScuGic_WriteReg(DistBaseAddress,
 					XSCUGIC_SPI_TARGET_OFFSET_CALC(Int_Id),
 					RegValue);
+	/*
+	 * Release the lock previously taken. This macro ensures that the lock
+	 * is given only if spinlock mechanism is enabled by the user.
+	 */
+	XIL_SPINUNLOCK();
 #endif
 }
+}
 
 /****************************************************************************/
 /**
@@ -700,33 +742,47 @@ void XScuGic_InterruptUnmapFromCpuByDistAddr(u32 DistBaseAddress,
 	u32 RegValue;
 #if !defined (GICv3)
 	u32 Offset;
+	u32 Cpu_CoreId;
 #endif
 
 	Xil_AssertVoid(Int_Id < XSCUGIC_MAX_NUM_INTR_INPUTS);
+
+if (Int_Id >= XSCUGIC_SPI_INT_ID_START) {
 #if defined (GICv3)
 	u32 Temp;
-	if (Int_Id >= 32 && Cpu_Id != 0) {
-		Temp = Int_Id - 32;
-		RegValue = XScuGic_ReadReg(DistBaseAddress,
-				XSCUGIC_IROUTER_OFFSET_CALC(Temp));
-		RegValue &= ~(Cpu_Id);
-		XScuGic_WriteReg(DistBaseAddress, XSCUGIC_IROUTER_OFFSET_CALC(Temp),
-			RegValue);
-	} else if (Cpu_Id == 0) {
-		xil_printf("Error: Unable to unmap interrupt id %d from core %d",Int_Id,Cpu_Id);
-	}
+	Temp = Int_Id - 32;
+	RegValue = XScuGic_ReadReg(DistBaseAddress,
+			XSCUGIC_IROUTER_OFFSET_CALC(Temp));
+	RegValue &= ~(Cpu_Id);
+	XScuGic_WriteReg(DistBaseAddress, XSCUGIC_IROUTER_OFFSET_CALC(Temp),
+		RegValue);
 #else
+    /*
+	 * Call spinlock to protect multiple applications running at separate
+	 * CPUs to write to the same register. This macro also ensures that
+	 * the spinlock mechanism is used only if spinlock is enabled by
+	 * user.
+	 */
+	XIL_SPINLOCK();
+
 	RegValue = XScuGic_ReadReg(DistBaseAddress,
 				XSCUGIC_SPI_TARGET_OFFSET_CALC(Int_Id));
 
 	Offset = (Int_Id & 0x3U);
-	Cpu_Id = (0x1U << Cpu_Id);
+	Cpu_CoreId = ((u32)0x1U << Cpu_Id);
 
-	RegValue &= ~(Cpu_Id << (Offset*8U));
+	RegValue &= ~(Cpu_CoreId << (Offset*8U));
 	XScuGic_WriteReg(DistBaseAddress,
 			XSCUGIC_SPI_TARGET_OFFSET_CALC(Int_Id), RegValue);
+
+	/*
+	 * Release the lock previously taken. This macro ensures that the lock
+	 * is given only if spinlock mechanism is enabled by the user.
+	 */
+	XIL_SPINUNLOCK();
 #endif
 }
+}
 
 /****************************************************************************/
 /**
@@ -746,7 +802,15 @@ void XScuGic_UnmapAllInterruptsFromCpuByDistAddr(u32 DistBaseAddress,
 {
 	u32 Int_Id;
 	u32 Target_Cpu;
-	u32 LocalCpuID = (1U << Cpu_Id);
+	u32 LocalCpuID = ((u32)1U << Cpu_Id);
+
+	/*
+	 * Call spinlock to protect multiple applications running at separate
+	 * CPUs to write to the same register. This macro also ensures that
+	 * the spinlock mechanism is used only if spinlock is enabled by
+	 * user.
+	 */
+	XIL_SPINLOCK();
 
 	LocalCpuID |= LocalCpuID << 8U;
 	LocalCpuID |= LocalCpuID << 16U;
@@ -762,6 +826,12 @@ void XScuGic_UnmapAllInterruptsFromCpuByDistAddr(u32 DistBaseAddress,
 			XSCUGIC_SPI_TARGET_OFFSET_CALC(Int_Id), Target_Cpu);
 
 	}
+
+	/*
+	 * Release the lock previously taken. This macro ensures that the lock
+	 * is given only if spinlock mechanism is enabled by the user.
+	 */
+	XIL_SPINUNLOCK();
 }
 
 /*****************************************************************************/
@@ -790,8 +860,6 @@ void XScuGic_EnableIntr (u32 DistBaseAddress, u32 Int_Id)
 
 #if defined (GICv3)
 	if (Int_Id < XSCUGIC_SPI_INT_ID_START) {
-		XScuGic_InterruptMapFromCpuByDistAddr(DistBaseAddress, Cpu_Id,
-			Int_Id);
 
 		Int_Id &= 0x1f;
 		Int_Id = 1 << Int_Id;
@@ -801,12 +869,25 @@ void XScuGic_EnableIntr (u32 DistBaseAddress, u32 Int_Id)
 		Temp |= Int_Id;
 		XScuGic_WriteReg(DistBaseAddress + XSCUGIC_RDIST_SGI_PPI_OFFSET,
 			XSCUGIC_RDIST_ISENABLE_OFFSET,Temp);
+		return;
 	}
 #endif
 
 	XScuGic_InterruptMapFromCpuByDistAddr(DistBaseAddress, Cpu_Id, Int_Id);
+	/*
+	 * Call spinlock to protect multiple applications running at separate
+	 * CPUs to write to the same register. This macro also ensures that
+	 * the spinlock mechanism is used only if spinlock is enabled by
+	 * user.
+	 */
+	XIL_SPINLOCK();
 	XScuGic_WriteReg((DistBaseAddress), XSCUGIC_ENABLE_SET_OFFSET +
-			(((Int_Id) / 32U) * 4U), (0x00000001U << ((Int_Id) % 32U)));
+			(((Int_Id) / 32U) * 4U), ((u32)0x00000001U << ((Int_Id) % 32U)));
+	/*
+	 * Release the lock previously taken. This macro ensures that the lock
+	 * is given only if spinlock mechanism is enabled by the user.
+	 */
+	XIL_SPINUNLOCK();
 }
 
 /*****************************************************************************/
@@ -836,9 +917,6 @@ void XScuGic_DisableIntr (u32 DistBaseAddress, u32 Int_Id)
 
 	if (Int_Id < XSCUGIC_SPI_INT_ID_START) {
 
-		XScuGic_InterruptUnmapFromCpuByDistAddr(DistBaseAddress +
-			XSCUGIC_RDIST_SGI_PPI_OFFSET, Cpu_Id, Int_Id);
-
 		Int_Id &= 0x1f;
 		Int_Id = 1 << Int_Id;
 
@@ -847,11 +925,24 @@ void XScuGic_DisableIntr (u32 DistBaseAddress, u32 Int_Id)
 		Temp &= ~Int_Id;
 		XScuGic_WriteReg(DistBaseAddress + XSCUGIC_RDIST_SGI_PPI_OFFSET,
 			XSCUGIC_RDIST_ISENABLE_OFFSET,Temp);
+		return;
 	}
 #endif
 	XScuGic_InterruptUnmapFromCpuByDistAddr(DistBaseAddress, Cpu_Id, Int_Id);
+	/*
+	 * Call spinlock to protect multiple applications running at separate
+	 * CPUs to write to the same register. This macro also ensures that
+	 * the spinlock mechanism is used only if spinlock is enabled by
+	 * user.
+	 */
+	XIL_SPINLOCK();
 	XScuGic_WriteReg((DistBaseAddress), XSCUGIC_DISABLE_OFFSET +
-			(((Int_Id) / 32U) * 4U), (0x00000001U << ((Int_Id) % 32U)));
+			(((Int_Id) / 32U) * 4U), ((u32)0x00000001U << ((Int_Id) % 32U)));
+	/*
+	 * Release the lock previously taken. This macro ensures that the lock
+	 * is given only if spinlock mechanism is enabled by the user.
+	 */
+	XIL_SPINUNLOCK();
 }
 
 /** @} */
