@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright (C) 2017 - 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (C) 2017 - 2021 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 *******************************************************************************/
 
@@ -7,7 +7,7 @@
 /**
  *
  * @file xhdmic.c
- * @addtogroup hdmi_common_v1_4
+ * @addtogroup hdmi_common_v1_6
  * @{
  *
  * Contains common utility functions that are typically used by hdmi-related
@@ -28,6 +28,8 @@
  * 1.3   EB  29/10/19 Fixed a bug where XV_HdmiC_AVIIF_GeneratePacket and
  *                        XV_HdmiC_AudioIF_GeneratePacket return incorrect Aux
  *           02/12/19 Added 3D Audio Enumerations and APIs
+ * 1.6   kp  15/07/21 Updated the VIC table as per latest CTA spec
+             30/08/21 Added missing video resolution IDs
  * </pre>
  *
 *******************************************************************************/
@@ -45,153 +47,172 @@
 * 2) Video Identification Code.
 */
 const XHdmiC_VicTable VicTable[VICTABLE_SIZE] = {
-    {XVIDC_VM_640x480_60_P, 1},      /* Vic 1 */
-    {XVIDC_VM_720x480_60_P, 2},      /* Vic 2 */
-    {XVIDC_VM_720x480_60_P, 3},      /* Vic 3 */
-    {XVIDC_VM_1280x720_60_P, 4},     /* Vic 4 */
-    {XVIDC_VM_1920x1080_60_I, 5},    /* Vic 5 */
-    {XVIDC_VM_1440x480_60_I, 6},     /* Vic 6 */
-    {XVIDC_VM_1440x480_60_I, 7},     /* Vic 7 */
-
-    {XVIDC_VM_1440x240_60_P, 8},     /* Vic 8 */
-    {XVIDC_VM_1440x240_60_P, 9},     /* Vic 9 */
-    {XVIDC_VM_2880x480_60_I, 10},    /* Vic 10 */
-    {XVIDC_VM_2880x480_60_I, 11},    /* Vic 11 */
-    {XVIDC_VM_2880x240_60_P, 12},    /* Vic 12 */
-    {XVIDC_VM_2880x240_60_P, 13},    /* Vic 13 */
-    {XVIDC_VM_1440x480_60_P, 14},    /* Vic 14 */
-    {XVIDC_VM_1440x480_60_P, 15},    /* Vic 15 */
-
-    {XVIDC_VM_1920x1080_60_P, 16},   /* Vic 16 */
-    {XVIDC_VM_720x576_50_P, 17},     /* Vic 17 */
-    {XVIDC_VM_720x576_50_P, 18},     /* Vic 18 */
-    {XVIDC_VM_1280x720_50_P, 19},    /* Vic 19 */
-    {XVIDC_VM_1920x1080_50_I, 20},   /* Vic 20 */
-    {XVIDC_VM_1440x576_50_I, 21},    /* Vic 21 */
-    {XVIDC_VM_1440x576_50_I, 22},    /* Vic 22 */
-
-    {XVIDC_VM_1440x288_50_P, 23},    /* Vic 23 */
-    {XVIDC_VM_1440x288_50_P, 24},    /* Vic 24 */
-    {XVIDC_VM_2880x576_50_I, 25},    /* Vic 25 */
-    {XVIDC_VM_2880x576_50_I, 26},    /* Vic 26 */
-    {XVIDC_VM_2880x288_50_P, 27},    /* Vic 27 */
-    {XVIDC_VM_2880x288_50_P, 28},    /* Vic 28 */
-    {XVIDC_VM_1440x576_50_P, 29},    /* Vic 29 */
-    {XVIDC_VM_1440x576_50_P, 30},    /* Vic 30 */
-    {XVIDC_VM_1920x1080_50_P, 31},   /* Vic 31 */
-    {XVIDC_VM_1920x1080_24_P, 32},   /* Vic 32 */
-    {XVIDC_VM_1920x1080_25_P, 33},   /* Vic 33 */
-    {XVIDC_VM_1920x1080_30_P, 34},   /* Vic 34 */
-    {XVIDC_VM_2880x480_60_P, 35},    /* Vic 35 */
-    {XVIDC_VM_2880x480_60_P, 36},    /* Vic 36 */
-    {XVIDC_VM_2880x576_50_P, 37},    /* Vic 37 */
-    {XVIDC_VM_2880x576_50_P, 38},    /* Vic 38 */
-    {XVIDC_VM_1920x1080_100_I, 40},  /* Vic 40 */
-    {XVIDC_VM_1280x720_100_P, 41},   /* Vic 41 */
-    {XVIDC_VM_720x576_100_P, 42},    /* Vic 42 */
-    {XVIDC_VM_720x576_100_P, 43},    /* Vic 43 */
-    {XVIDC_VM_1440x576_100_I, 44},   /* Vic 44 */
-    {XVIDC_VM_1440x576_100_I, 45},   /* Vic 45 */
-    {XVIDC_VM_1920x1080_120_I, 46},  /* Vic 46 */
-    {XVIDC_VM_1280x720_120_P, 47},   /* Vic 47 */
-    {XVIDC_VM_720x480_120_P, 48},    /* Vic 48 */
-    {XVIDC_VM_720x480_120_P, 49},    /* Vic 49 */
-    {XVIDC_VM_1440x480_120_I, 50},   /* Vic 50 */
-    {XVIDC_VM_1440x480_120_I, 51},   /* Vic 51 */
-    {XVIDC_VM_720x576_200_P, 52},    /* Vic 52 */
-    {XVIDC_VM_720x576_200_P, 53},    /* Vic 53 */
-    {XVIDC_VM_1440x576_200_I, 54},   /* Vic 54 */
-    {XVIDC_VM_1440x576_200_I, 55},   /* Vic 55 */
-    {XVIDC_VM_720x480_240_P, 56},    /* Vic 56 */
-    {XVIDC_VM_720x480_240_P, 57},    /* Vic 57 */
-    {XVIDC_VM_1440x480_240_I, 58},   /* Vic 58 */
-    {XVIDC_VM_1440x480_240_I, 59},   /* Vic 59 */
-    {XVIDC_VM_1280x720_24_P, 60},    /* Vic 60 */
-    {XVIDC_VM_1280x720_25_P, 61},    /* Vic 61 */
-    {XVIDC_VM_1280x720_30_P, 62},    /* Vic 62 */
-    {XVIDC_VM_1920x1080_120_P, 63},  /* Vic 63 */
-    {XVIDC_VM_1920x1080_100_P, 64},  /* Vic 64 */
-
-    /* 1280 x 720 */
-    {XVIDC_VM_1280x720_24_P, 65},    /* Vic 65 */
-    {XVIDC_VM_1280x720_25_P, 66},    /* Vic 66 */
-    {XVIDC_VM_1280x720_30_P, 67},    /* Vic 67 */
-    {XVIDC_VM_1280x720_50_P, 68},    /* Vic 68 */
-    {XVIDC_VM_1280x720_60_P, 69},    /* Vic 69 */
-    {XVIDC_VM_1280x720_100_P, 70},   /* Vic 70 */
-    {XVIDC_VM_1280x720_120_P, 71},   /* Vic 71 */
-
-    /* 1680 x 720 */
-    {XVIDC_VM_1680x720_24_P, 79},    /* Vic 82 */
-    {XVIDC_VM_1680x720_25_P, 80},    /* Vic 82 */
-    {XVIDC_VM_1680x720_30_P, 81},    /* Vic 82 */
-    {XVIDC_VM_1680x720_50_P, 82},    /* Vic 82 */
-    {XVIDC_VM_1680x720_60_P, 83},    /* Vic 83 */
-    {XVIDC_VM_1680x720_100_P, 84},   /* Vic 84 */
-    {XVIDC_VM_1680x720_120_P, 85},   /* Vic 85 */
-
-    /* 1920 x 1080 */
-    {XVIDC_VM_1920x1080_24_P, 72},   /* Vic 32 */
-    {XVIDC_VM_1920x1080_25_P, 73},   /* Vic 33 */
-    {XVIDC_VM_1920x1080_30_P, 74},   /* Vic 34 */
-    {XVIDC_VM_1920x1080_50_P, 75},   /* Vic 75 */
-    {XVIDC_VM_1920x1080_60_P, 76},   /* Vic 76 */
-    {XVIDC_VM_1920x1080_100_P, 77},  /* Vic 77 */
-    {XVIDC_VM_1920x1080_120_P, 78},  /* Vic 78 */
-
-    /* 2560 x 1080 */
-    {XVIDC_VM_2560x1080_24_P, 86},   /* Vic 86 */
-    {XVIDC_VM_2560x1080_25_P, 87},   /* Vic 87 */
-    {XVIDC_VM_2560x1080_30_P, 88},   /* Vic 88 */
-    {XVIDC_VM_2560x1080_50_P, 89},   /* Vic 89 */
-    {XVIDC_VM_2560x1080_60_P, 90},   /* Vic 90 */
-    {XVIDC_VM_2560x1080_100_P, 91},  /* Vic 91 */
-    {XVIDC_VM_2560x1080_120_P, 92},  /* Vic 92 */
-
-    /* 3840 x 2160 */
-    {XVIDC_VM_3840x2160_24_P, 93},   /* Vic 93  */
-    {XVIDC_VM_3840x2160_25_P, 94},   /* Vic 94  */
-    {XVIDC_VM_3840x2160_30_P, 95},   /* Vic 95  */
-    {XVIDC_VM_3840x2160_50_P, 96},   /* Vic 96  */
-    {XVIDC_VM_3840x2160_60_P, 97},   /* Vic 97  */
-    {XVIDC_VM_3840x2160_100_P, 117}, /* Vic 117 */
-    {XVIDC_VM_3840x2160_120_P, 118}, /* Vic 118 */
-
-    /* 4096 x 2160 */
-    {XVIDC_VM_4096x2160_24_P, 98},   /* Vic 98  */
-    {XVIDC_VM_4096x2160_25_P, 99},   /* Vic 99  */
-    {XVIDC_VM_4096x2160_30_P, 100},  /* Vic 100 */
-    {XVIDC_VM_4096x2160_50_P, 101},  /* Vic 101 */
-    {XVIDC_VM_4096x2160_60_P, 102},  /* Vic 102 */
-    {XVIDC_VM_4096x2160_100_P, 218}, /* Vic 218 */
-    {XVIDC_VM_4096x2160_120_P, 219}, /* Vic 219 */
-
-    /* 5120 x 2160 */
-    {XVIDC_VM_5120x2160_24_P, 121},  /* Vic 121 */
-    {XVIDC_VM_5120x2160_25_P, 122},  /* Vic 122 */
-    {XVIDC_VM_5120x2160_30_P, 123},  /* Vic 123 */
-    {XVIDC_VM_5120x2160_50_P, 125},  /* Vic 125 */
-    {XVIDC_VM_5120x2160_60_P, 126},  /* Vic 126 */
-    {XVIDC_VM_5120x2160_100_P, 127}, /* Vic 127 */
-    {XVIDC_VM_5120x2160_120_P, 193}, /* Vic 193 */
-
-    /* 7680 x 4320 */
-    {XVIDC_VM_7680x4320_24_P, 194},  /* Vic 194 */
-    {XVIDC_VM_7680x4320_25_P, 195},  /* Vic 195 */
-    {XVIDC_VM_7680x4320_30_P, 196},  /* Vic 196 */
-    {XVIDC_VM_7680x4320_50_P, 198},  /* Vic 198 */
-    {XVIDC_VM_7680x4320_60_P, 199},  /* Vic 199 */
-    {XVIDC_VM_7680x4320_100_P, 200}, /* Vic 200 */
-    {XVIDC_VM_7680x4320_120_P, 201}, /* Vic 201 */
-
-    /* 10240 x 4320 */
-    {XVIDC_VM_10240x4320_24_P, 210},  /* Vic 210 */
-    {XVIDC_VM_10240x4320_25_P, 211},  /* Vic 211 */
-    {XVIDC_VM_10240x4320_30_P, 212},  /* Vic 212 */
-    {XVIDC_VM_10240x4320_50_P, 214},  /* Vic 214 */
-    {XVIDC_VM_10240x4320_60_P, 215},  /* Vic 215 */
-    {XVIDC_VM_10240x4320_100_P, 216}, /* Vic 216 */
-    {XVIDC_VM_10240x4320_120_P, 217}, /* Vic 217 */
+	{ XVIDC_VM_640x480_60_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 1 },
+	{ XVIDC_VM_720x480_60_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 2 },
+	{ XVIDC_VM_720x480_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 3 },
+	{ XVIDC_VM_1280x720_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 4 },
+	{ XVIDC_VM_1920x1080_60_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 5 },
+	{ XVIDC_VM_1440x480_60_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 6 },
+	{ XVIDC_VM_1440x480_60_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 7 },
+	{ XVIDC_VM_1440x240_60_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 8 },
+	{ XVIDC_VM_1440x240_60_P_VT263, XHDMIC_PIC_ASPECT_RATIO_4_3, 8},
+	{ XVIDC_VM_1440x240_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 9 },
+	{ XVIDC_VM_1440x240_60_P_VT263, XHDMIC_PIC_ASPECT_RATIO_16_9, 9},
+	{ XVIDC_VM_2880x480_60_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 10 },
+	{ XVIDC_VM_2880x480_60_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 11 },
+	{ XVIDC_VM_2880x240_60_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 12 },
+	{ XVIDC_VM_2880x240_60_P_VT263, XHDMIC_PIC_ASPECT_RATIO_4_3, 12},
+	{ XVIDC_VM_2880x240_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 13 },
+	{ XVIDC_VM_2880x240_60_P_VT263, XHDMIC_PIC_ASPECT_RATIO_16_9, 13},
+	{ XVIDC_VM_1440x480_60_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 14 },
+	{ XVIDC_VM_1440x480_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 15 },
+	{ XVIDC_VM_1920x1080_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 16 },
+	{ XVIDC_VM_720x576_50_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 17 },
+	{ XVIDC_VM_720x576_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 18 },
+	{ XVIDC_VM_1280x720_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 19 },
+	{ XVIDC_VM_1920x1080_50_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 20 },
+	{ XVIDC_VM_1440x576_50_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 21 },
+	{ XVIDC_VM_1440x576_50_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 22 },
+	{ XVIDC_VM_1440x288_50_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 23 },
+	{ XVIDC_VM_1440x288_50_P_VT312, XHDMIC_PIC_ASPECT_RATIO_4_3, 23},
+	{ XVIDC_VM_1440x288_50_P_VT314, XHDMIC_PIC_ASPECT_RATIO_4_3, 23},
+	{ XVIDC_VM_1440x288_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 24 },
+	{ XVIDC_VM_1440x288_50_P_VT312, XHDMIC_PIC_ASPECT_RATIO_16_9, 24},
+	{ XVIDC_VM_1440x288_50_P_VT314, XHDMIC_PIC_ASPECT_RATIO_16_9, 24},
+	{ XVIDC_VM_2880x576_50_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 25 },
+	{ XVIDC_VM_2880x576_50_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 26 },
+	{ XVIDC_VM_2880x288_50_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 27 },
+	{ XVIDC_VM_2880x288_50_P_VT312, XHDMIC_PIC_ASPECT_RATIO_4_3, 27},
+	{ XVIDC_VM_2880x288_50_P_VT314, XHDMIC_PIC_ASPECT_RATIO_4_3, 27},
+	{ XVIDC_VM_2880x288_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 28 },
+	{ XVIDC_VM_2880x288_50_P_VT312, XHDMIC_PIC_ASPECT_RATIO_16_9, 28},
+	{ XVIDC_VM_2880x288_50_P_VT314, XHDMIC_PIC_ASPECT_RATIO_16_9, 28},
+	{ XVIDC_VM_1440x576_50_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 29 },
+	{ XVIDC_VM_1440x576_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 30 },
+	{ XVIDC_VM_1920x1080_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 31 },
+	{ XVIDC_VM_1920x1080_24_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 32 },
+	{ XVIDC_VM_1920x1080_25_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 33 },
+	{ XVIDC_VM_1920x1080_30_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 34 },
+	{ XVIDC_VM_2880x480_60_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 35 },
+	{ XVIDC_VM_2880x480_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 36 },
+	{ XVIDC_VM_2880x576_50_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 37 },
+	{ XVIDC_VM_2880x576_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 38 },
+	{ XVIDC_VM_1920x1080_50_I_VT1250, XHDMIC_PIC_ASPECT_RATIO_16_9, 39 },
+	{ XVIDC_VM_1920x1080_100_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 40 },
+	{ XVIDC_VM_1280x720_100_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 41 },
+	{ XVIDC_VM_720x576_100_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 42 },
+	{ XVIDC_VM_720x576_100_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 43 },
+	{ XVIDC_VM_1440x576_100_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 44 },
+	{ XVIDC_VM_1440x576_100_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 45 },
+	{ XVIDC_VM_1920x1080_120_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 46 },
+	{ XVIDC_VM_1280x720_120_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 47 },
+	{ XVIDC_VM_720x480_120_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 48 },
+	{ XVIDC_VM_720x480_120_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 49 },
+	{ XVIDC_VM_1440x480_120_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 50 },
+	{ XVIDC_VM_1440x480_120_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 51 },
+	{ XVIDC_VM_720x576_200_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 52 },
+	{ XVIDC_VM_720x576_200_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 53 },
+	{ XVIDC_VM_1440x576_200_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 54 },
+	{ XVIDC_VM_1440x576_200_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 55 },
+	{ XVIDC_VM_720x480_240_P, XHDMIC_PIC_ASPECT_RATIO_4_3, 56 },
+	{ XVIDC_VM_720x480_240_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 57 },
+	{ XVIDC_VM_1440x480_240_I, XHDMIC_PIC_ASPECT_RATIO_4_3, 58 },
+	{ XVIDC_VM_1440x480_240_I, XHDMIC_PIC_ASPECT_RATIO_16_9, 59 },
+	{ XVIDC_VM_1280x720_24_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 60 },
+	{ XVIDC_VM_1280x720_25_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 61 },
+	{ XVIDC_VM_1280x720_30_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 62 },
+	{ XVIDC_VM_1920x1080_120_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 63 },
+	{ XVIDC_VM_1920x1080_100_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 64 },
+	{ XVIDC_VM_1280x720_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 65 },
+	{ XVIDC_VM_1280x720_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 66 },
+	{ XVIDC_VM_1280x720_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 67 },
+	{ XVIDC_VM_1280x720_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 68 },
+	{ XVIDC_VM_1280x720_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 69 },
+	{ XVIDC_VM_1280x720_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 70 },
+	{ XVIDC_VM_1280x720_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 71 },
+	{ XVIDC_VM_1920x1080_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 72 },
+	{ XVIDC_VM_1920x1080_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 73 },
+	{ XVIDC_VM_1920x1080_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 74 },
+	{ XVIDC_VM_1920x1080_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 75 },
+	{ XVIDC_VM_1920x1080_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 76 },
+	{ XVIDC_VM_1920x1080_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 77 },
+	{ XVIDC_VM_1920x1080_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 78 },
+	{ XVIDC_VM_1680x720_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 79 },
+	{ XVIDC_VM_1680x720_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 80 },
+	{ XVIDC_VM_1680x720_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 81 },
+	{ XVIDC_VM_1680x720_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 82 },
+	{ XVIDC_VM_1680x720_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 83 },
+	{ XVIDC_VM_1680x720_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 84 },
+	{ XVIDC_VM_1680x720_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 85 },
+	{ XVIDC_VM_2560x1080_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 86 },
+	{ XVIDC_VM_2560x1080_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 87 },
+	{ XVIDC_VM_2560x1080_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 88 },
+	{ XVIDC_VM_2560x1080_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 89 },
+	{ XVIDC_VM_2560x1080_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 90 },
+	{ XVIDC_VM_2560x1080_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 91 },
+	{ XVIDC_VM_2560x1080_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 92 },
+	{ XVIDC_VM_3840x2160_24_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 93 },
+	{ XVIDC_VM_3840x2160_25_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 94 },
+	{ XVIDC_VM_3840x2160_30_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 95 },
+	{ XVIDC_VM_3840x2160_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 96 },
+	{ XVIDC_VM_3840x2160_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 97 },
+	{ XVIDC_VM_4096x2160_24_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 98 },
+	{ XVIDC_VM_4096x2160_25_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 99 },
+	{ XVIDC_VM_4096x2160_30_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 100 },
+	{ XVIDC_VM_4096x2160_50_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 101 },
+	{ XVIDC_VM_4096x2160_60_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 102 },
+	{ XVIDC_VM_3840x2160_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 103 },
+	{ XVIDC_VM_3840x2160_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 104 },
+	{ XVIDC_VM_3840x2160_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 105 },
+	{ XVIDC_VM_3840x2160_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 106 },
+	{ XVIDC_VM_3840x2160_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 107 },
+	{ XVIDC_VM_1280x720_48_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 108 },
+	{ XVIDC_VM_1280x720_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 109 },
+	{ XVIDC_VM_1680x720_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 110 },
+	{ XVIDC_VM_1920x1080_48_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 111 },
+	{ XVIDC_VM_1920x1080_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 112 },
+	{ XVIDC_VM_2560x1080_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 113 },
+	{ XVIDC_VM_3840x2160_48_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 114 },
+	{ XVIDC_VM_4096x2160_48_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 115 },
+	{ XVIDC_VM_3840x2160_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 116 },
+	{ XVIDC_VM_3840x2160_100_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 117 },
+	{ XVIDC_VM_3840x2160_120_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 118 },
+	{ XVIDC_VM_3840x2160_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 119 },
+	{ XVIDC_VM_3840x2160_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 120 },
+	{ XVIDC_VM_5120x2160_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 121 },
+	{ XVIDC_VM_5120x2160_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 122 },
+	{ XVIDC_VM_5120x2160_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 123 },
+	{ XVIDC_VM_5120x2160_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 124 },
+	{ XVIDC_VM_5120x2160_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 125 },
+	{ XVIDC_VM_5120x2160_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 126 },
+	{ XVIDC_VM_5120x2160_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 127 },
+	{ XVIDC_VM_5120x2160_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 193 },
+	{ XVIDC_VM_7680x4320_24_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 194 },
+	{ XVIDC_VM_7680x4320_25_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 195 },
+	{ XVIDC_VM_7680x4320_30_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 196 },
+	{ XVIDC_VM_7680x4320_48_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 197 },
+	{ XVIDC_VM_7680x4320_50_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 198 },
+	{ XVIDC_VM_7680x4320_60_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 199 },
+	{ XVIDC_VM_7680x4320_100_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 200 },
+	{ XVIDC_VM_7680x4320_120_P, XHDMIC_PIC_ASPECT_RATIO_16_9, 201 },
+	{ XVIDC_VM_7680x4320_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 202 },
+	{ XVIDC_VM_7680x4320_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 203 },
+	{ XVIDC_VM_7680x4320_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 204 },
+	{ XVIDC_VM_7680x4320_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 205 },
+	{ XVIDC_VM_7680x4320_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 206 },
+	{ XVIDC_VM_7680x4320_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 207 },
+	{ XVIDC_VM_7680x4320_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 208 },
+	{ XVIDC_VM_7680x4320_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 209 },
+	{ XVIDC_VM_10240x4320_24_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 210 },
+	{ XVIDC_VM_10240x4320_25_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 211 },
+	{ XVIDC_VM_10240x4320_30_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 212 },
+	{ XVIDC_VM_10240x4320_48_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 213 },
+	{ XVIDC_VM_10240x4320_50_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 214 },
+	{ XVIDC_VM_10240x4320_60_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 215 },
+	{ XVIDC_VM_10240x4320_100_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 216 },
+	{ XVIDC_VM_10240x4320_120_P, XHDMIC_PIC_ASPECT_RATIO_64_27, 217 },
+	{ XVIDC_VM_4096x2160_100_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 218 },
+	{ XVIDC_VM_4096x2160_120_P, XHDMIC_PIC_ASPECT_RATIO_256_135, 219 },
 };
 
 /**
@@ -1203,7 +1224,7 @@ XHdmiC_Aux XV_HdmiC_SPDIF_GeneratePacket(XHdmiC_SPDInfoFrame *SPDInfoFrame)
 		Crc += aux.Header.Byte[Index];
 
 	/* Data */
-	for (Index = 1; Index < aux.Header.Byte[2] + 1; Index++)
+	for (Index = 1; Index < aux.Header.Byte[2] + 4; Index++)
 		Crc += aux.Data.Byte[Index];
 
 	Crc = 256 - Crc;
@@ -1300,7 +1321,7 @@ void XV_HdmiC_DRMIF_GeneratePacket(XHdmiC_DRMInfoFrame *DRMInfoFrame, XHdmiC_Aux
 		Crc += aux->Header.Byte[Index];
 
 	/* Data */
-	for (Index = 1; Index < aux->Header.Byte[2] + 1; Index++)
+	for (Index = 1; Index < aux->Header.Byte[2] + 4; Index++)
 		Crc += aux->Data.Byte[Index];
 
 	Crc = 256 - Crc;
