@@ -1,30 +1,8 @@
 /******************************************************************************
-*
-* Copyright (C) 2016 - 2017  Xilinx, Inc. All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (C) 2016 - 2020  Xilinx, Inc. All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 *
@@ -148,6 +126,7 @@
 *       YB     15/08/18	Added new callbacks for HDCP 1.4 & 2.2 protocol events.
 *                       Enumerated new entries for HDCP 1.4 & 2.2 protocol
 *                           events in XV_HdmiRx_HandlerType enum.
+* 2.50  EB     02/12/18 Added 3D Audio Support
 * </pre>
 *
 ******************************************************************************/
@@ -195,7 +174,8 @@ typedef enum {
 	XV_HDMIRX_HANDLER_LINK_ERROR,		/**< Interrupt type for link error */
 	XV_HDMIRX_HANDLER_SYNC_LOSS,       /**< Interrupt type for sync loss */
 	XV_HDMIRX_HANDLER_MODE,            /**< Interrupt type for mode */
-    XV_HDMIRX_HANDLER_TMDS_CLK_RATIO /**< Interrupt type for TMDS clock ratio */
+	XV_HDMIRX_HANDLER_TMDS_CLK_RATIO, /**< Interrupt type for TMDS clock ratio */
+	XV_HDMIRX_HANDLER_VIC_ERROR	/**< Interrupt type for VIC error */
 } XV_HdmiRx_HandlerType;
 /*@}*/
 
@@ -225,8 +205,9 @@ typedef enum {
 */
 typedef enum {
 	XV_HDMIRX_AUDFMT_UNKNOWN = 0,
-    XV_HDMIRX_AUDFMT_LPCM,     // L-PCM
-    XV_HDMIRX_AUDFMT_HBR       // HBR
+	XV_HDMIRX_AUDFMT_LPCM,	// L-PCM
+	XV_HDMIRX_AUDFMT_HBR,	// HBR
+	XV_HDMIRX_AUDFMT_3D	// 3D Audio
 } XV_HdmiRx_AudioFormatType;
 
 
@@ -360,6 +341,10 @@ typedef struct {
 	void *TmdsClkRatioRef;                  /**< To be passed to the TMDS callback */
 	u32 IsTmdsClkRatioCallbackSet;          /**< Set flag. This flag is set to true when the callback has been registered */
 
+	XV_HdmiRx_Callback VicErrorCallback;	/**< Callback for Vic error detection */
+	void *VicErrorRef;			/**< To be passed to the vic error callback */
+	u32 IsVicErrorCallbackSet;		/**< Set flag. This flag is set to true when the callback has been registered */
+
 	/* HDMI RX stream */
 	XV_HdmiRx_Stream Stream;				/**< HDMI RX stream information */
 
@@ -1292,6 +1277,7 @@ int XV_HdmiRx_GetTmdsClockRatio(XV_HdmiRx *InstancePtr);
 u8 XV_HdmiRx_GetAviVic(XV_HdmiRx *InstancePtr);
 XVidC_ColorFormat XV_HdmiRx_GetAviColorSpace(XV_HdmiRx *InstancePtr);
 XVidC_ColorDepth XV_HdmiRx_GetGcpColorDepth(XV_HdmiRx *InstancePtr);
+XVidC_VideoMode XV_HdmiRx_LookupVmId(u8 Vic);
 int XV_HdmiRx_GetVideoProperties(XV_HdmiRx *InstancePtr);
 int XV_HdmiRx_GetVideoTiming(XV_HdmiRx *InstancePtr);
 u32 XV_HdmiRx_Divide(u32 Dividend, u32 Divisor);
@@ -1304,7 +1290,10 @@ int XV_HdmiRx_SelfTest(XV_HdmiRx *InstancePtr);
 
 /* Interrupt related function in xv_hdmirx_intr.c */
 void XV_HdmiRx_IntrHandler(void *InstancePtr);
-int XV_HdmiRx_SetCallback(XV_HdmiRx *InstancePtr, u32 HandlerType, void *CallbackFunc, void *CallbackRef);
+int XV_HdmiRx_SetCallback(XV_HdmiRx *InstancePtr,
+		XV_HdmiRx_HandlerType HandlerType,
+		void *CallbackFunc,
+		void *CallbackRef);
 
 /* Vendor Specific Infomation related functions in xv_hdmirx_vsif.c */
 int XV_HdmiRx_VSIF_ParsePacket(XHdmiC_Aux *AuxPtr, XV_HdmiRx_VSIF  *VSIFPtr);
