@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright (C) 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (C) 2021 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 *******************************************************************************/
 
@@ -7,7 +7,7 @@
 /**
  *
  * @file xvidc.c
- * @addtogroup video_common_v4_10
+ * @addtogroup video_common_v4_13
  * @{
  *
  * Contains common utility functions that are typically used by video-related
@@ -840,8 +840,11 @@ const char *XVidC_GetColorFormatStr(XVidC_ColorFormat ColorFormatId)
 		case XVIDC_CSF_MEM_Y_UV16_420: return ("Y_UV16_420");
 		case XVIDC_CSF_MEM_Y12:        return ("Y12");
 		case XVIDC_CSF_MEM_Y16:        return ("Y16");
+		case XVIDC_CSF_MEM_R_G_B8:     return ("R_G_B8");
+		case XVIDC_CSF_MEM_Y_U_V8_420: return ("Y_U_V8_420");
+		case XVIDC_CSF_MEM_Y_U_V8:     return ("Y_U_V8");
 		default:
-					       return ("Color space format not supported");
+			return ("Color space format not supported");
 	}
 }
 
@@ -1063,35 +1066,50 @@ void XVidC_ReportStreamInfo(const XVidC_VideoStream *Stream)
 		return;
 	}
 
-	xil_printf("\tColor Format:     %s\r\n",
+	xil_printf("\tColor Format:             %s\r\n",
 			XVidC_GetColorFormatStr(Stream->ColorFormatId));
-	xil_printf("\tColor Depth:      %d\r\n", Stream->ColorDepth);
-	xil_printf("\tPixels Per Clock: %d\r\n", Stream->PixPerClk);
-	xil_printf("\tMode:             %s\r\n",
+	xil_printf("\tColor Depth:              %d\r\n", Stream->ColorDepth);
+	xil_printf("\tPixels Per Clock:         %d\r\n", Stream->PixPerClk);
+	xil_printf("\tMode:                     %s\r\n",
 			Stream->IsInterlaced ? "Interlaced" : "Progressive");
+	xil_printf("\tDSC Status:               %s\r\n",
+			Stream->IsDSCompressed? "Compressed" : "Uncompressed");
 
 	if (Stream->Is3D) {
-		xil_printf("\t3D Format:        %s\r\n",
+		xil_printf("\t3D Format:                %s\r\n",
 		XVidC_Get3DFormatStr(Stream->Info_3D.Format));
 	}
 
 	if (Stream->VmId == XVIDC_VM_CUSTOM) {
-		xil_printf("\tFrame Rate:       %dHz\r\n",
+		xil_printf("\tFrame Rate:               %dHz\r\n",
 				Stream->FrameRate);
-		xil_printf("\tResolution:       %dx%d [Custom Mode]\r\n",
-				Stream->Timing.HActive, Stream->Timing.VActive);
-		xil_printf("\tPixel Clock:      %d kHz\r\n",
-				(u32)XVidC_GetPixelClockHzByHVFr(
-					Stream->Timing.HTotal,
-					Stream->Timing.F0PVTotal,
-					Stream->FrameRate)/1000);
+		if (Stream->IsDSCompressed) {
+			xil_printf("\tResolution[Compressed]:   %dx%d [Custom Mode]\r\n",
+				   Stream->Timing.HActive,
+				   Stream->Timing.VActive);
+			xil_printf("\tResolution[Uncompressed]: %dx%d\r\n",
+				   Stream->UncompressedTiming.HActive,
+				   Stream->UncompressedTiming.VActive);
+			xil_printf("\tPixel Clock[Compressed]:  %u KHz\r\n",
+				   (u32)XVidC_GetPixelClockHzByHVFr(Stream->Timing.HTotal,
+								    Stream->Timing.F0PVTotal,
+								    Stream->FrameRate) / 1000);
+		} else {
+			xil_printf("\tResolution:               %dx%d [Custom Mode]\r\n",
+				   Stream->Timing.HActive, Stream->Timing.VActive);
+			xil_printf("\tPixel Clock:              %d kHz\r\n",
+				   (u32)XVidC_GetPixelClockHzByHVFr(
+								    Stream->Timing.HTotal,
+								    Stream->Timing.F0PVTotal,
+								    Stream->FrameRate)/1000);
+		}
 	}
 	else {
-		xil_printf("\tFrame Rate:       %s\r\n",
+		xil_printf("\tFrame Rate:               %s\r\n",
 				XVidC_GetFrameRateStr(Stream->VmId));
-		xil_printf("\tResolution:       %s\r\n",
+		xil_printf("\tResolution:               %s\r\n",
 				XVidC_GetVideoModeStr(Stream->VmId));
-		xil_printf("\tPixel Clock:      %d kHz\r\n",
+		xil_printf("\tPixel Clock:              %d kHz\r\n",
 				(u32)XVidC_GetPixelClockHzByVmId(Stream->VmId)/1000);
 	}
 }
