@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright (C) 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (C) 2021 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 *******************************************************************************/
 
@@ -7,7 +7,7 @@
 /**
  *
  * @file xvidc_timings_table.c
- * @addtogroup video_common_v4_10
+ * @addtogroup video_common_v4_13
  * @{
  *
  * Contains video timings for various standard resolutions.
@@ -32,6 +32,9 @@
  *                         1280x720_30_P
  * 4.5	 jsr  07/03/18 Added timing for new video mode XVIDC_VM_720x486_60_I
  * 4.6   mmo  02/14/19 Added 5k, 8k, 10k and Low Resolution with 200Hz, 240Hz
+ * 4.12  kp   15/07/21 Added new video timing modes
+ *       kp   24/08/21 Corrected the vpolarity, vfreq and vactive
+         kp   24/08/21 Added new video timing modes
  * </pre>
  *
 *******************************************************************************/
@@ -105,6 +108,9 @@ const XVidC_VideoTimingMode XVidC_VideoTimingModes[XVIDC_VM_NUM_SUPPORTED] =
 	{ XVIDC_VM_1920x1080_50_I, "1920x1080@50Hz (I)", XVIDC_FR_50HZ,
 		{1920, 528, 44, 148, 2640, 1,
 		540, 2, 5, 15, 562, 3, 5, 15, 563, 1} },
+	{ XVIDC_VM_1920x1080_50_I_VT1250,"1920x1080@50Hz (I)", XVIDC_FR_50HZ,
+	        {1920, 32, 168, 184, 2304, 1,
+		540, 23, 5, 57, 625, 23, 5, 57, 625, 0} },
 	{ XVIDC_VM_1920x1080_60_I, "1920x1080@60Hz (I)", XVIDC_FR_60HZ,
 		{1920, 88, 44, 148, 2200, 1,
 		540, 2, 5, 15, 562, 3, 5, 15, 563, 1} },
@@ -140,15 +146,15 @@ const XVidC_VideoTimingMode XVidC_VideoTimingModes[XVIDC_VM_NUM_SUPPORTED] =
 		240, 4, 3, 15, 262, 5, 3, 15, 263, 0} },
 	{XVIDC_VM_2880x576_50_I, "2880x576@50Hz (I)", XVIDC_FR_50HZ,
 		{2880, 48, 252, 276, 3456, 0,
-		576, 2, 3, 19, 312, 2, 3, 19, 313, 0} },
+		288, 2, 3, 19, 312, 3, 3, 19, 313, 0} },
 
 	/* Progressive modes. */
 	{ XVIDC_VM_640x350_85_P, "640x350@85Hz", XVIDC_FR_85HZ,
 		{640, 32, 64, 96, 832, 1,
 		350, 32, 3, 60, 445, 0, 0, 0, 0, 0} },
 	{ XVIDC_VM_640x480_60_P, "640x480@60Hz", XVIDC_FR_60HZ,
-		{640, 8+8, 96, 40+8, 800, 0,
-		480, 2+8, 2, 25+8, 525, 0, 0, 0, 0, 0} },
+		{640, 16, 96, 48, 800, 0,
+		480, 10, 2, 33, 525, 0, 0, 0, 0, 0} },
 	{ XVIDC_VM_640x480_72_P, "640x480@72Hz", XVIDC_FR_72HZ,
 		{640, 8+16, 40, 120+8, 832, 0,
 		480, 8+1, 3, 20+8, 520, 0, 0, 0, 0, 0} },
@@ -227,6 +233,9 @@ const XVidC_VideoTimingMode XVidC_VideoTimingModes[XVIDC_VM_NUM_SUPPORTED] =
 	{ XVIDC_VM_1280x720_30_P, "1280x720@30Hz", XVIDC_FR_30HZ,
 		{1280, 1760, 40, 220, 3300, 1,
 		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
+	{ XVIDC_VM_1280x720_48_P, "1280x720@48Hz", XVIDC_FR_48HZ,
+	        {1280, 960, 40, 220, 2500, 1,
+		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
 	{ XVIDC_VM_1280x720_50_P, "1280x720@50Hz", XVIDC_FR_50HZ,
 		{1280, 440, 40, 220, 1980, 1,
 		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
@@ -319,14 +328,23 @@ const XVidC_VideoTimingMode XVidC_VideoTimingModes[XVIDC_VM_NUM_SUPPORTED] =
 		1050, 3, 4, 55, 1112, 0, 0, 0, 0, 0} },
 	{ XVIDC_VM_1440x240_60_P, "1440x240@60Hz", XVIDC_FR_60HZ,
 		{1440, 38, 124, 114, 1716, 0,
-		240, 4, 3, 15, 262, 0, 0, 0, 0, 1} },
-	{XVIDC_VM_1440x288_50_P, "1440x288@50Hz", XVIDC_FR_50HZ,
+		240, 4, 3, 15, 262, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_1440x240_60_P_VT263, "1440x240@60Hz", XVIDC_FR_60HZ,
+	        {1440, 38, 124, 114, 1716, 0,
+		240, 5, 3, 15, 263, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_1440x288_50_P, "1440x288@50Hz", XVIDC_FR_50HZ,
 		{1440, 24, 126, 138, 1728, 0,
 		288, 3, 3, 19, 313, 0, 0, 0, 0, 0} },
-	{ XVIDC_VM_1440x480_60_P, "1440x240@60Hz", XVIDC_FR_60HZ,
+	{ XVIDC_VM_1440x288_50_P_VT314, "1440x288@50Hz", XVIDC_FR_50HZ,
+	        {1440, 24, 126, 138, 1728, 0,
+		288, 4, 3, 19, 314, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_1440x288_50_P_VT312,"1440x288@50Hz", XVIDC_FR_50HZ,
+	        {1440, 24, 126, 138, 1728, 0,
+		288, 2, 3, 19, 312, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_1440x480_60_P, "1440x480@60Hz", XVIDC_FR_60HZ,
 		{1440, 32, 124, 120, 1716, 0,
 		480, 9, 6, 30, 525, 0, 0, 0, 0, 0} },
-	{XVIDC_VM_1440x576_50_P, "1440x576@50Hz", XVIDC_FR_50HZ,
+	{ XVIDC_VM_1440x576_50_P, "1440x576@50Hz", XVIDC_FR_50HZ,
 		{1440, 24, 128, 136, 1728, 0,
 		576, 5, 5, 39, 625, 0, 0, 0, 0, 0} },
 	{ XVIDC_VM_1440x900_60_P, "1440x900@60Hz", XVIDC_FR_60HZ,
@@ -364,13 +382,16 @@ const XVidC_VideoTimingMode XVidC_VideoTimingModes[XVIDC_VM_NUM_SUPPORTED] =
 		1200, 3, 4, 64, 1271, 0, 0, 0, 0, 0} },
 	{XVIDC_VM_1680x720_24_P, "1680x720@24Hz", XVIDC_FR_24HZ,
 		{1680, 1360, 40, 220, 3300, 1,
-		720, 5, 5, 20, 750, 0, 0, 0, 0, 0} },
+		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
 	{XVIDC_VM_1680x720_25_P, "1680x720@25Hz", XVIDC_FR_25HZ,
 		{1680, 1228, 40, 220, 3168, 1,
-		720, 5, 5, 20, 750, 0, 0, 0, 0, 0} },
+		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
 	{XVIDC_VM_1680x720_30_P, "1680x720@30Hz", XVIDC_FR_30HZ,
 		{1680, 700, 40, 220, 2640, 1,
-		720, 5, 5, 20, 750, 0, 0, 0, 0, 0} },
+		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
+	{XVIDC_VM_1680x720_48_P, "1680x720@48Hz", XVIDC_FR_48HZ,
+	        {1680, 810, 40, 220, 2750, 1,
+		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
 	{ XVIDC_VM_1680x720_50_P, "1680x720@50Hz", XVIDC_FR_50HZ,
 		{1680, 260, 40, 220, 2200, 1,
 		720, 5, 5, 20, 750, 0, 0, 0, 0, 1} },
@@ -535,10 +556,19 @@ const XVidC_VideoTimingMode XVidC_VideoTimingModes[XVIDC_VM_NUM_SUPPORTED] =
 		1600, 3, 6, 85, 1694, 0, 0, 0, 0, 0} },
 	{ XVIDC_VM_2880x240_60_P, "2880x240@60Hz", XVIDC_FR_60HZ,
 		{2880, 76, 248, 228, 3432, 0,
-		240, 14, 3, 4, 262, 0, 0, 0, 0, 1} },
+		240, 4, 3, 15, 262, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_2880x240_60_P_VT263, "2880x240@60Hz", XVIDC_FR_60HZ,
+	        {2880, 76, 248, 228, 3432, 0,
+		240, 5, 3, 15, 263, 0, 0, 0, 0, 0} },
 	{ XVIDC_VM_2880x288_50_P, "2880x288@50Hz", XVIDC_FR_50HZ,
 		{2880, 48, 252, 276, 3456, 0,
 		288, 3, 3, 19, 313, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_2880x288_50_P_VT314, "2880x288@50Hz", XVIDC_FR_50HZ,
+	        {2880, 48, 252, 276, 3456, 0,
+		288, 4, 3, 19, 314, 0, 0, 0, 0, 0} },
+	{ XVIDC_VM_2880x288_50_P_VT312,"2880x288@50Hz", XVIDC_FR_50HZ,
+	        {2880, 48, 252, 276, 3456, 0,
+		288, 2, 3, 19, 312, 0, 0, 0, 0, 0} },
 	{XVIDC_VM_2880x480_60_P, "2880x480@60Hz", XVIDC_FR_60HZ,
 		{2880, 64, 248, 240, 3432, 0,
 		480, 9, 6, 30, 525, 0, 0, 0, 0, 0} },
