@@ -1,30 +1,7 @@
 /******************************************************************************
- *
- * Copyright (C) 2015 - 2018 Xilinx, Inc.  All rights reserved.
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
- * XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
- * OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
- *
- * Except as contained in this notice, the name of the Xilinx shall not be used
- * in advertising or otherwise to promote the sale, use or other dealings in
- * this Software without prior written authorization from Xilinx.
- *
- ******************************************************************************/
+* SPDX-License-Identifier: MIT
+******************************************************************************/
+
 /*****************************************************************************/
 /**
  *
@@ -40,13 +17,19 @@
  * 5.2	pkp  28/05/15 First release
  * 5.5	pkp	 04/15/16 Updated the Xil_DCacheInvalidate,
  *			Xil_DCacheInvalidateLine and Xil_DCacheInvalidateRange
- *			functions description for proper explaination
+ *			functions description for proper explanation
  * 6.8  aru  06/15/18 Removed unused variables.
  * 6.8	aru  07/04/18 Optimized code in Xil_DCacheInvalidate and
  *			Xil_DCacheFlush
  * 6.8  asa  11/10/18 Fix issues in cache Xil_DCacheInvalidate and
  * 			Xil_DCacheFlush that got introduced in the optimization
  * 			changes done in the previous patch for this file.
+ * 7.7  mus  02/21/22 Existing note in cache API's says, "bottom 4 bits of input
+ *                    address are forced to 0 as per architecture". As cache line
+ *                    length is of 32 byte, bottom 5 bits of input address would
+ *                    be forced to 0. Updated note to have correct details.
+ *                    It fixes CR#1122561.
+ * </pre>
  *
  ******************************************************************************/
  /***************************** Include Files *********************************/
@@ -73,12 +56,8 @@ extern s32  __undef_stack;
 /**
  * @brief	Enable the Data cache.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @note	None.
- *
  ****************************************************************************/
 void Xil_DCacheEnable(void)
 {
@@ -102,12 +81,8 @@ void Xil_DCacheEnable(void)
 /**
  * @brief	Disable the Data cache.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @note	None.
- *
  ****************************************************************************/
 void Xil_DCacheDisable(void)
 {
@@ -126,11 +101,9 @@ void Xil_DCacheDisable(void)
  * @brief	Invalidate the Data cache. The contents present in
  *		the data cache are cleaned and invalidated.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @note	In Cortex-A53, functionality to simply invalide the
+ * @note	In Cortex-A53, functionality to simply invalid the
  *		cachelines is not present. Such operations are a
  *		problem for an environment that supports virtualisation.
  *		It would allow one OS to invalidate a line belonging to
@@ -220,7 +193,7 @@ void Xil_DCacheInvalidate(void)
  *
  * @return	None.
  *
- * @note	In Cortex-A53, functionality to simply invalide
+ * @note	In Cortex-A53, functionality to simply invalid
  *		the cachelines is not present. Such operations
  *		are a problem for an environment that supports
  *		virtualisation. It would allow one OS to invalidate
@@ -264,7 +237,7 @@ void Xil_DCacheInvalidateLine(u32 adr)
  *
  * @return	None.
  *
- * @notice	In Cortex-A53, functionality to simply invalide the cachelines
+ * @note	In Cortex-A53, functionality to simply invalid the cachelines
  *		is not present. Such operations are a problem for an
  *		environment that supports virtualisation. It would allow
  *		one OS to invalidate a line belonging to another OS.
@@ -322,12 +295,8 @@ void Xil_DCacheInvalidateRange(INTPTR adr, u32 len)
 /**
  * @brief	Flush the Data cache.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @notice	None.
- *
  ****************************************************************************/
 void Xil_DCacheFlush(void)
 {
@@ -403,7 +372,7 @@ void Xil_DCacheFlush(void)
  *
  * @return	None.
  *
- * @notice	The bottom 4 bits are set to 0, forced by architecture.
+ * @note	The bottom 5 bits are set to 0, forced by architecture.
  *
  ****************************************************************************/
 void Xil_DCacheFlushLine(u32 adr)
@@ -429,7 +398,7 @@ void Xil_DCacheFlushLine(u32 adr)
 }
 
 /****************************************************************************/
-/*
+/**
  * @brief	Flush the Data cache for the given address range.
  *		If the bytes specified by the address range are cached
  *		by the Data cache, the cachelines containing those bytes
@@ -442,8 +411,6 @@ void Xil_DCacheFlushLine(u32 adr)
  *
  * @return	None.
  *
- * @notice	None.
- *
  ****************************************************************************/
 void Xil_DCacheFlushRange(INTPTR adr, u32 len)
 {
@@ -494,12 +461,8 @@ void Xil_DCacheFlushRange(INTPTR adr, u32 len)
 /**
  * @brief	Enable the instruction cache.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @notice	None.
- *
  ****************************************************************************/
 void Xil_ICacheEnable(void)
 {
@@ -520,12 +483,8 @@ void Xil_ICacheEnable(void)
 /**
  * @brief	Disable the instruction cache.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @note		None.
- *
  ****************************************************************************/
 void Xil_ICacheDisable(void)
 {
@@ -544,12 +503,8 @@ void Xil_ICacheDisable(void)
 /**
  * @brief	Invalidate the entire instruction cache.
  *
- * @param	None.
- *
  * @return	None.
  *
- * @note	None.
- *
  ****************************************************************************/
 void Xil_ICacheInvalidate(void)
 {
@@ -575,7 +530,7 @@ void Xil_ICacheInvalidate(void)
  *
  * @return	None.
  *
- * @notice	The bottom 4 bits are set to 0, forced by architecture.
+ * @note	The bottom 5 bits are set to 0, forced by architecture.
  *
  ****************************************************************************/
 void Xil_ICacheInvalidateLine(u32 adr)
@@ -605,8 +560,6 @@ void Xil_ICacheInvalidateLine(u32 adr)
  *
  * @return	None.
  *
- * @notice	None.
- *
  ****************************************************************************/
 void Xil_ICacheInvalidateRange(INTPTR adr, u32 len)
 {
