@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright (c) 2018 - 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (c) 2018 - 2022 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 ******************************************************************************/
 
@@ -21,6 +21,21 @@
 * 7.3   asa  09/25/20 Make changes to update the global array
 *                     Mpu_Config for the static regions created
 *                     during boot up.
+* 7.5   mus  01/13/21 Removed redundant declaration for Mpu_Config,
+*                     declaration is present in xil_mpu.h.
+* 7.5   asa  03/07/21 Ensure that Update_MpuConfig_Array stays in .boot section
+*                     as it is used only during bootup.
+*                     Add function header to Init_MPU function.
+* 7.7	sk   01/10/22 Update unsigned int to u32 to fix misra_c_2012_directive_4_6
+* 		      violation.
+* 7.7	sk   01/10/22 Update values from signed to unsigned to fix misrac
+* 		      misra_c_2012_rule_10_4 violation.
+* 7.7	sk   01/10/22 Add explicit parentheses for region_size and region_size[0]
+* 		      to fix misra_c_2012_rule_12_1 violation.
+* 7.7	sk   01/10/22 Typecast variables to unsigned to fix misra_c_2012_rule_10_3
+* 		      violation.
+* 7.7	sk   01/10/22 Add unsigned to hexadecimal value to fix misra_c_2012_rule_7_2
+* 		      violation.
 * </pre>
 *
 * @note
@@ -46,7 +61,7 @@
 
 static const struct {
 	u64 size;
-	unsigned int encoding;
+	u32 encoding;
 }region_size[] = {
 	{ 0x20, REGION_32B },
 	{ 0x40, REGION_64B },
@@ -81,15 +96,14 @@ static const struct {
 /************************** Function Prototypes ******************************/
 #if defined (__GNUC__)
 void Init_MPU(void) __attribute__((__section__(".boot")));
-static void Xil_SetAttribute(u32 addr, u32 reg_size,s32 reg_num, u32 attrib) __attribute__((__section__(".boot")));
+static void Xil_SetAttribute(u32 addr, u32 reg_size,u32 reg_num, u32 attrib) __attribute__((__section__(".boot")));
 static void Xil_DisableMPURegions(void) __attribute__((__section__(".boot")));
-extern XMpu_Config Mpu_Config __attribute__((section(".boot")));
+static inline void Update_MpuConfig_Array(u32 Addr,u32 RegSize,u32 RegNum, u32 Attrib) __attribute__((__section__(".boot")));
 #elif defined (__ICCARM__)
 #pragma default_function_attributes = @ ".boot"
 void Init_MPU(void);
-static void Xil_SetAttribute(u32 addr, u32 reg_size,s32 reg_num, u32 attrib);
+static void Xil_SetAttribute(u32 addr, u32 reg_size,u32 reg_num, u32 attrib);
 static void Xil_DisableMPURegions(void);
-extern XMpu_Config Mpu_Config;
 #endif
 /*****************************************************************************
 *
@@ -112,6 +126,16 @@ static inline void Update_MpuConfig_Array(u32 Addr,u32 RegSize,u32 RegNum,
 	Mpu_Config[RegNum].Attribute = Attrib;
 }
 
+/*****************************************************************************
+*
+* Initialize MPU for during bootup with predefined region attributes.
+*
+* @param	None.
+*
+* @return	None.
+*
+*
+******************************************************************************/
 void Init_MPU(void)
 {
 	u32 Addr;
@@ -126,9 +150,9 @@ void Init_MPU(void)
 #ifdef	XPAR_AXI_NOC_DDR_LOW_0_BASEADDR
 	/* If the DDR is present, configure region as per DDR size */
 	size = (XPAR_AXI_NOC_DDR_LOW_0_HIGHADDR - XPAR_AXI_NOC_DDR_LOW_0_BASEADDR) + 1;
-	if (size < 0x80000000) {
+	if (size < 0x80000000U) {
 		/* Lookup the size.  */
-		for (i = 0; i < sizeof region_size / sizeof region_size[0]; i++) {
+		for (i = 0; i < (sizeof (region_size) / sizeof (region_size[0])); i++) {
 			if (size <= region_size[i].size) {
 				RegSize = region_size[i].encoding;
 				break;
@@ -162,7 +186,7 @@ void Init_MPU(void)
 	 *
 	 *
 	 */
-	Addr = 0x80000000;
+	Addr = 0x80000000U;
 	RegSize = REGION_1G;
 	Attrib = STRONG_ORDERD_SHARED | PRIV_RW_USER_RW   ;
 	Xil_SetAttribute(Addr,RegSize,RegNum, Attrib);
@@ -278,7 +302,7 @@ void Init_MPU(void)
 *
 *
 ******************************************************************************/
-static void Xil_SetAttribute(u32 addr, u32 reg_size,s32 reg_num, u32 attrib)
+static void Xil_SetAttribute(u32 addr, u32 reg_size,u32 reg_num, u32 attrib)
 {
 	u32 Local_reg_size = reg_size;
 
@@ -309,7 +333,7 @@ static void Xil_DisableMPURegions(void)
 {
 	u32 Temp = 0U;
 	u32 Index = 0U;
-	for (Index = 0; Index <= 15; Index++) {
+	for (Index = 0; Index <= 15U; Index++) {
 		mtcp(XREG_CP15_MPU_MEMORY_REG_NUMBER,Index);
 #if defined (__GNUC__)
 		Temp = mfcp(XREG_CP15_MPU_REG_SIZE_EN);
