@@ -1,30 +1,8 @@
 /******************************************************************************
-*
-* Copyright (C) 2014 - 2015 Xilinx, Inc. All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (c) 2014 - 2022 Xilinx, Inc.  All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 *
@@ -39,6 +17,16 @@
 * ----- ---- -------- -----------------------------------------------
 * 5.00 	pkp  02/20/14 First release
 * 6.2   mus  01/27/17 Updated to support IAR compiler
+* 7.3   dp   06/25/20 Updated to support armclang compiler
+* 7.7	sk   01/10/22 Update IRQ_FIQ_MASK macro from signed to unsigned
+* 		      to fix misra_c_2012_rule_10_4 violation.
+* 7.7	sk   01/10/22 Typecast to fix wider essential type misra_c_2012_rule_10_7
+* 		      violation.
+* 7.7   mus  02/21/22 Existing note in cache API's says, "bottom 4 bits of input
+*                     address are forced to 0 as per architecture". As cache line
+*                     length is of 32 byte, bottom 5 bits of input address would
+*                     be forced to 0. Updated note to have correct details.
+*                     It fixes CR#1122561.
 * </pre>
 *
 ******************************************************************************/
@@ -55,12 +43,16 @@
 
 /************************** Variable Definitions *****************************/
 
-#define IRQ_FIQ_MASK 0xC0	/* Mask IRQ and FIQ interrupts in cpsr */
+#define IRQ_FIQ_MASK 0xC0U	/* Mask IRQ and FIQ interrupts in cpsr */
 
-#if defined (__GNUC__)
+#if defined (__clang__)
+extern s32  Image$$ARM_LIB_STACK$$Limit;
+extern s32  Image$$ARM_UNDEF_STACK$$Base;
+#elif defined (__GNUC__)
 extern s32  _stack_end;
 extern s32  __undef_stack;
 #endif
+
 /****************************************************************************/
 /************************** Function Prototypes ******************************/
 
@@ -68,12 +60,8 @@ extern s32  __undef_stack;
 /**
 * @brief    Enable the Data cache.
 *
-* @param	None.
-*
 * @return	None.
 *
-* @note		None.
-*
 ****************************************************************************/
 void Xil_DCacheEnable(void)
 {
@@ -100,12 +88,8 @@ void Xil_DCacheEnable(void)
 /**
 * @brief    Disable the Data cache.
 *
-* @param	None.
-*
 * @return	None.
 *
-* @note		None.
-*
 ****************************************************************************/
 void Xil_DCacheDisable(void)
 {
@@ -130,8 +114,6 @@ void Xil_DCacheDisable(void)
 /**
 * @brief    Invalidate the entire Data cache.
 *
-* @param	None.
-*
 * @return	None.
 *
 ****************************************************************************/
@@ -143,14 +125,21 @@ void Xil_DCacheInvalidate(void)
 	currmask = mfcpsr();
 	mtcpsr(currmask | IRQ_FIQ_MASK);
 
-#if defined (__GNUC__)
+#if defined (__clang__)
+	stack_end = (u32 )&Image$$ARM_LIB_STACK$$Limit;
+	stack_start = (u32 )&Image$$ARM_UNDEF_STACK$$Base;
+#elif defined (__GNUC__)
 	stack_end = (u32 )&_stack_end;
 	stack_start = (u32 )&__undef_stack;
+#endif
+
+#if defined(__GNUC__) || defined(__clang__)
 	stack_size = stack_start-stack_end;
 
 	/* Flush stack memory to save return address */
 	Xil_DCacheFlushRange(stack_end, stack_size);
 #endif
+
 	mtcp(XREG_CP15_CACHE_SIZE_SEL, 0);
 
 	/*invalidate all D cache*/
@@ -172,7 +161,7 @@ void Xil_DCacheInvalidate(void)
 *
 * @return	None.
 *
-* @note		The bottom 4 bits are set to 0, forced by architecture.
+* @note		The bottom 5 bits are set to 0, forced by architecture.
 *
 ****************************************************************************/
 void Xil_DCacheInvalidateLine(INTPTR adr)
@@ -251,8 +240,6 @@ void Xil_DCacheInvalidateRange(INTPTR adr, u32 len)
 /**
 * @brief    Flush the entire Data cache.
 *
-* @param	None.
-*
 * @return	None.
 *
 ****************************************************************************/
@@ -288,7 +275,7 @@ void Xil_DCacheFlush(void)
 	LineSize = (CsidReg & 0x00000007U) + 0x00000004U;
 
 	NumSet = CacheSize/NumWays;
-	NumSet /= (0x00000001U << LineSize);
+	NumSet /= (((u32)0x00000001U) << LineSize);
 
 	Way = 0U;
 	Set = 0U;
@@ -300,7 +287,7 @@ void Xil_DCacheFlush(void)
 			/* Flush by Set/Way */
 			asm_clean_inval_dc_line_sw(C7Reg);
 
-			Set += (0x00000001U << LineSize);
+			Set += (((u32)0x00000001U) << LineSize);
 		}
 		Set = 0U;
 		Way += 0x40000000U;
@@ -325,7 +312,7 @@ void Xil_DCacheFlush(void)
 *
 * @return	None.
 *
-* @note		The bottom 4 bits are set to 0, forced by architecture.
+* @note		The bottom 5 bits are set to 0, forced by architecture.
 *
 ****************************************************************************/
 void Xil_DCacheFlushLine(INTPTR adr)
@@ -397,7 +384,7 @@ void Xil_DCacheFlushRange(INTPTR adr, u32 len)
 *
 * @return	None.
 *
-* @note		The bottom 4 bits are set to 0, forced by architecture.
+* @note		The bottom 5 bits are set to 0, forced by architecture.
 *
 ****************************************************************************/
 void Xil_DCacheStoreLine(INTPTR adr)
@@ -421,8 +408,6 @@ void Xil_DCacheStoreLine(INTPTR adr)
 /**
 * @brief    Enable the instruction cache.
 *
-* @param	None.
-*
 * @return	None.
 *
 ****************************************************************************/
@@ -451,8 +436,6 @@ void Xil_ICacheEnable(void)
 /**
 * @brief    Disable the instruction cache.
 *
-* @param	None.
-*
 * @return	None.
 *
 ****************************************************************************/
@@ -481,8 +464,6 @@ void Xil_ICacheDisable(void)
 /**
 * @brief    Invalidate the entire instruction cache.
 *
-* @param	None.
-*
 * @return	None.
 *
 ****************************************************************************/
@@ -513,7 +494,7 @@ void Xil_ICacheInvalidate(void)
 *
 * @return	None.
 *
-* @note		The bottom 4 bits are set to 0, forced by architecture.
+* @note		The bottom 5 bits are set to 0, forced by architecture.
 *
 ****************************************************************************/
 void Xil_ICacheInvalidateLine(INTPTR adr)
