@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright (c) 2014 - 2020 Xilinx, Inc.  All rights reserved.
+* Copyright (c) 2014 - 2022 Xilinx, Inc.  All rights reserved.
 * SPDX-License-Identifier: MIT
 ******************************************************************************/
 
@@ -27,6 +27,26 @@
 * 					  represent the MPU configuration table.
 * 6.8  aru  07/02/18 Returned the pointer instead of address
 *			of that pointer in Xil_MemMap().
+* 7.5  asa  03/01/21  Ensure that Mpu_Config does not stay in .boot/.vector
+*                     sections which generally should be executable code
+*                     which can be allocated and not written.
+*                     Mpu_Config array is populated during boot time, hence
+*                     cannot be placed in .bss or .data section. Putting
+*                     Mpu_Config in a new .bootdata section.
+* 7.7  sk   01/10/22  Update int to u32 to fix misrac misra_c_2012_directive_4_6
+* 		      violations.
+* 7.7  sk   01/10/22  Typecast variables from signed to unsigned to fix
+* 		      misra_c_2012_rule_10_4 violation.
+* 7.7  sk   01/10/22  Add explicit parentheses for region_size and region_size[0]
+* 		      to fix misra_c_2012_rule_12_1 violation.
+* 7.7  sk   01/10/22  Remove unsigned sign to fix misra_c_2012_rule_10_3 violation.
+* 7.7  sk   01/10/22  Modify if condition to fix misra_c_2012_rule_10_1 violation.
+* 7.7  sk   01/10/22  Typecast to fix wider essential type misra_c_2012_rule_10_7
+* 		      violation.
+* 7.7  sk   01/10/22  Update conditional expression to fix misra_c_2012_rule_14_4
+* 		      violation.
+* 7.7  sk   01/10/22  Add braces for the if statement to make it a compound
+* 		      statement to fix misra_c_2012_rule_15_6 violation.
 * </pre>
 *
 *
@@ -50,7 +70,7 @@
 
 static const struct {
 	u64 size;
-	unsigned int encoding;
+	u32 encoding;
 }region_size[] = {
 	{ 0x20, REGION_32B },
 	{ 0x40, REGION_64B },
@@ -83,9 +103,9 @@ static const struct {
 };
 
 #if defined (__GNUC__)
-XMpu_Config Mpu_Config __attribute__((section(".boot")));
+XMpu_Config Mpu_Config __attribute__((section(".bootdata")));
 #elif defined (__ICCARM__)
-#pragma default_function_attributes = @ ".boot"
+#pragma default_function_attributes = @ ".bootdata"
 XMpu_Config Mpu_Config;
 #endif
 
@@ -96,7 +116,7 @@ void Xil_InitializeExistingMPURegConfig(void);
 * @brief    This function sets the memory attributes for a section covering
 *           1MB, of memory in the translation table.
 *
-* @param	Addr: 32-bit address for which memory attributes need to be set.
+* @param	addr: 32-bit address for which memory attributes need to be set.
 * @param	attrib: Attribute for the given memory region.
 * @return	None.
 *
@@ -105,7 +125,7 @@ void Xil_InitializeExistingMPURegConfig(void);
 void Xil_SetTlbAttributes(INTPTR addr, u32 attrib)
 {
 	INTPTR Localaddr = addr;
-	Localaddr &= (~(0xFFFFFU));
+	Localaddr &= (INTPTR)(~(0xFFFFFU));
 	/* Setting the MPU region with given attribute with 1MB size */
 	Xil_SetMPURegion(Localaddr, 0x100000, attrib);
 }
@@ -115,7 +135,7 @@ void Xil_SetTlbAttributes(INTPTR addr, u32 attrib)
 * @brief    Set the memory attributes for a section of memory in the
 *           translation table.
 *
-* @param	Addr: 32-bit address for which memory attributes need to be set..
+* @param	addr: 32-bit address for which memory attributes need to be set..
 * @param	size: size is the size of the region.
 * @param	attrib: Attribute for the given memory region.
 * @return	None.
@@ -127,10 +147,10 @@ u32 Xil_SetMPURegion(INTPTR addr, u64 size, u32 attrib)
 	u32 Regionsize = 0;
 	INTPTR Localaddr = addr;
 	u32 NextAvailableMemRegion;
-	unsigned int i;
+	u32 i;
 
 	NextAvailableMemRegion = Xil_GetNextMPURegion();
-	if (NextAvailableMemRegion == 0xFF) {
+	if (NextAvailableMemRegion == 0xFFU) {
 		xdbg_printf(DEBUG, "No regions available\r\n");
 		return XST_FAILURE;
 	}
@@ -142,14 +162,14 @@ u32 Xil_SetMPURegion(INTPTR addr, u64 size, u32 attrib)
 	isb();
 
 	/* Lookup the size.  */
-	for (i = 0; i < sizeof region_size / sizeof region_size[0]; i++) {
+	for (i = 0; i < (sizeof (region_size) / sizeof (region_size[0])); i++) {
 		if (size <= region_size[i].size) {
 			Regionsize = region_size[i].encoding;
 			break;
 		}
 	}
 
-	Localaddr &= ~(region_size[i].size - 1);
+	Localaddr &= (INTPTR)(~(region_size[i].size - 1U));
 
 	Regionsize <<= 1;
 	Regionsize |= REGION_EN;
@@ -167,8 +187,6 @@ u32 Xil_SetMPURegion(INTPTR addr, u64 size, u32 attrib)
 * @brief    Enable MPU for Cortex R5 processor. This function invalidates I
 *           cache and flush the D Caches, and then enables the MPU.
 *
-*
-* @param	None.
 * @return	None.
 *
 ******************************************************************************/
@@ -218,8 +236,6 @@ void Xil_EnableMPU(void)
 * @brief    Disable MPU for Cortex R5 processors. This function invalidates I
 *           cache and flush the D Caches, and then disabes the MPU.
 *
-* @param	None.
-*
 * @return	None.
 *
 ******************************************************************************/
@@ -293,14 +309,14 @@ u32 Xil_UpdateMPUConfig(u32 reg_num, INTPTR address, u32 size, u32 attrib)
 		goto exit;
 	}
 
-	if (size & REGION_EN) {
+	if ((size & REGION_EN) != 0) {
 		Mpu_Config[reg_num].RegionStatus = MPU_REG_ENABLED;
 		Mpu_Config[reg_num].BaseAddress = address;
 		Tempsize &= (~REGION_EN);
 		Tempsize >>= 1;
 		/* Lookup the size.  */
 		for (Index = 0; Index <
-				sizeof region_size / sizeof region_size[0]; Index++) {
+				(sizeof (region_size) / sizeof (region_size[0])); Index++) {
 			if (Tempsize <= region_size[Index].encoding) {
 				Mpu_Config[reg_num].Size = region_size[Index].size;
 				break;
@@ -309,7 +325,7 @@ u32 Xil_UpdateMPUConfig(u32 reg_num, INTPTR address, u32 size, u32 attrib)
 		Mpu_Config[reg_num].Attribute = attrib;
 	} else {
 		Mpu_Config[reg_num].RegionStatus = 0U;
-		Mpu_Config[reg_num].BaseAddress = 0U;
+		Mpu_Config[reg_num].BaseAddress = 0;
 		Mpu_Config[reg_num].Size = 0U;
 		Mpu_Config[reg_num].Attribute = 0U;
 	}
@@ -344,14 +360,13 @@ void Xil_GetMPUConfig (XMpu_Config mpuconfig) {
 /**
 * @brief    Returns the total number of free MPU regions available.
 *
-* @param	none
 * @return	Number of free regions available to users
 *
 *
 ******************************************************************************/
 u32 Xil_GetNumOfFreeRegions (void) {
 	u32 Index = 0U;
-	int NumofFreeRegs = 0U;
+	u32 NumofFreeRegs = 0U;
 
 	while (Index < MAX_POSSIBLE_MPU_REGS) {
 		if (MPU_REG_DISABLED == Mpu_Config[Index].RegionStatus) {
@@ -370,7 +385,6 @@ u32 Xil_GetNumOfFreeRegions (void) {
 *           For example, if this function returns 0xC0000, this would mean, the
 *           regions 14 and 15 are available to users.
 *
-* @param	none
 * @return	The free region mask as a 16 bit value
 *
 *
@@ -381,7 +395,7 @@ u16 Xil_GetMPUFreeRegMask (void) {
 
 	while (Index < MAX_POSSIBLE_MPU_REGS) {
 		if (MPU_REG_DISABLED == Mpu_Config[Index].RegionStatus) {
-			FreeRegMask |= (1U << Index);
+			FreeRegMask |= ((u16)1U << Index);
 		}
 		Index++;
 	}
@@ -420,7 +434,7 @@ u32 Xil_DisableMPURegionByRegNum (u32 reg_num) {
 	mtcp(XREG_CP15_MPU_REG_SIZE_EN,Temp);
 	dsb();
 	isb();
-	Xil_UpdateMPUConfig(reg_num, 0U, 0U, 0U);
+	Xil_UpdateMPUConfig(reg_num, 0, 0U, 0U);
 	ReturnVal = XST_SUCCESS;
 
 exit1:
@@ -432,7 +446,7 @@ exit1:
 * @brief    Enables the corresponding region number as passed by the user.
 *
 * @param	reg_num: The region number to be enabled
-* @param	address: 32 bit address for start of the region.
+* @param	addr: 32 bit address for start of the region.
 * @param	size: Requested size of the region.
 * @param	attrib: Attribute for the corresponding region.
 * @return	XST_SUCCESS: If the region could be created successfully
@@ -466,14 +480,14 @@ u32 Xil_SetMPURegionByRegNum (u32 reg_num, INTPTR addr, u64 size, u32 attrib)
 
 	/* Lookup the size.  */
 	for (Index = 0; Index <
-			sizeof region_size / sizeof region_size[0]; Index++) {
+			(sizeof (region_size) / sizeof (region_size[0])); Index++) {
 		if (size <= region_size[Index].size) {
 			Regionsize = region_size[Index].encoding;
 			break;
 		}
 	}
 
-	Localaddr &= ~(region_size[Index].size - 1);
+	Localaddr &= (INTPTR)(~(region_size[Index].size - 1U));
 	Regionsize <<= 1;
 	Regionsize |= REGION_EN;
 	dsb();
@@ -493,7 +507,6 @@ exit2:
 * @brief    Initializes the MPU configuration table that are setup in the
 * 			R5 boot code in the Init_Mpu function called before C main.
 *
-* @param	none
 * @return	none
 *
 *
@@ -518,7 +531,7 @@ void Xil_InitializeExistingMPURegConfig(void)
 		mfcp(XREG_CP15_MPU_REG_BASEADDR, MPURegBA);
 		mfcp(XREG_CP15_MPU_REG_ACCESS_CTRL, MPURegAttrib);
 #endif
-		if (MPURegSize & REGION_EN) {
+		if ((MPURegSize & REGION_EN) != 0) {
 			Mpu_Config[Index].RegionStatus = MPU_REG_ENABLED;
 			Mpu_Config[Index].BaseAddress = MPURegBA;
 			Mpu_Config[Index].Attribute = MPURegAttrib;
@@ -540,7 +553,6 @@ void Xil_InitializeExistingMPURegConfig(void)
 /**
 * @brief    Returns the next available free MPU region
 *
-* @param	none
 * @return	The free MPU region available
 *
 *
@@ -559,9 +571,18 @@ u32 Xil_GetNextMPURegion(void)
 	return NextAvailableReg;
 }
 
+#ifdef __GNUC__
+#define u32overflow(a, b) ({typeof(a) s; __builtin_uadd_overflow(a, b, &s); })
+#else
+#define u32overflow(a, b) ((a) > ((a) + (b)))
+#endif /* __GNUC__ */
+
 /*****************************************************************************/
 /**
-* @brief       Memory mapping for Cortex r5.
+* @brief    Memory mapping for Cortex-R5F. If successful, the mapped
+*           region will include all of the memory requested, but may
+*           include more. Specifically, it will be a power of 2 in
+*           size, aligned on a boundary of that size.
 *
 * @param       Physaddr is base physical address at which to start mapping.
 *                   NULL in Physaddr masks possible mapping errors.
@@ -570,37 +591,37 @@ u32 Xil_GetNextMPURegion(void)
 *
 * @return      Physaddr on success, NULL on error. Ambiguous if Physaddr==NULL
 *
+* @cond Xil_MemMap_internal
 * @note:    u32overflow() is defined for readability and (for __GNUC__) to
 *           - force the type of the check to be the same as the first argument
 *           - hide the otherwise unused third argument of the builtin
 *           - improve safety by choosing the explicit _uadd_ version.
 *           Consider __builtin_add_overflow_p() when available.
 *           Use an alternative (less optimal?) for compilers w/o the builtin.
-*
+* @endcond
 ******************************************************************************/
-#ifdef __GNUC__
-#define u32overflow(a, b) ({typeof(a) s; __builtin_uadd_overflow(a, b, &s); })
-#else
-#define u32overflow(a, b) ((a) > ((a) + (b)))
-#endif /* __GNUC__ */
 void *Xil_MemMap(UINTPTR Physaddr, size_t size, u32 flags)
 {
 	size_t Regionsize = MPU_REGION_SIZE_MIN;
 	UINTPTR Basephysaddr = 0, end = Physaddr + size;
 
-	if (!flags)
+	if (flags == 0U) {
 		return (void *)Physaddr;
-	if (u32overflow(Physaddr, size))
+	}
+	if (u32overflow(Physaddr, size)) {
 		return NULL;
-	for ( ; Regionsize != 0; Regionsize <<= 1) {
+	}
+	for ( ; Regionsize != 0U; Regionsize <<= 1) {
 		if (Regionsize >= size) {
-			Basephysaddr = Physaddr & ~(Regionsize - 1);
-			if (u32overflow(Basephysaddr, Regionsize))
+			Basephysaddr = Physaddr & ~(Regionsize - 1U);
+			if (u32overflow(Basephysaddr, Regionsize)) {
 				break;
-			if ((Basephysaddr + Regionsize) >= end)
-				return Xil_SetMPURegion(Basephysaddr,
-					Regionsize, flags) == XST_SUCCESS ?
-					(void *)Physaddr : NULL;
+			}
+			if ((Basephysaddr + Regionsize) >= end) {
+				return ((Xil_SetMPURegion(Basephysaddr,
+					Regionsize, flags) == XST_SUCCESS) ?
+					(void *)Physaddr : NULL);
+			}
 		}
 	}
 	return NULL;
