@@ -1,30 +1,8 @@
 /******************************************************************************
-*
-* Copyright (C) 2006 - 2014 Xilinx, Inc. All rights reserved.
-*
-* Permission is hereby granted, free of charge, to any person obtaining a copy
-* of this software and associated documentation files (the "Software"), to deal
-* in the Software without restriction, including without limitation the rights
-* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-* copies of the Software, and to permit persons to whom the Software is
-* furnished to do so, subject to the following conditions:
-*
-* The above copyright notice and this permission notice shall be included in
-* all copies or substantial portions of the Software.
-*
-* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-* XILINX  BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-* WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-* OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-* SOFTWARE.
-*
-* Except as contained in this notice, the name of the Xilinx shall not be used
-* in advertising or otherwise to promote the sale, use or other dealings in
-* this Software without prior written authorization from Xilinx.
-*
+* Copyright (c) 2006 - 2021 Xilinx, Inc.  All rights reserved.
+* SPDX-License-Identifier: MIT
 ******************************************************************************/
+
 /*****************************************************************************/
 /**
 *
@@ -50,6 +28,9 @@
 * @{
 *
 ******************************************************************************/
+/**
+ *@cond nocomments
+ */
 
 #ifndef _PVR_H
 #define _PVR_H
@@ -204,6 +185,9 @@ typedef struct pvr_s {
 #define MICROBLAZE_PVR11_MMU_ZONES_MASK             0x003E0000
 #define MICROBLAZE_PVR11_MMU_PRIVILEGED_INSTR_MASK  0x00010000
 
+/**
+ *@endcond
+ */
 /* PVR access macros */
 
 /**
@@ -241,6 +225,10 @@ Return non-zero integer if D-cache present.
 @param _pvr     pvr data structure
 */
 #define MICROBLAZE_PVR_USE_DCACHE(_pvr)              (_pvr.pvr[0] & MICROBLAZE_PVR0_USE_DCACHE_MASK)
+
+/**
+ *@cond nocomments
+ */
 #define MICROBLAZE_PVR_USE_MMU(_pvr)                 (_pvr.pvr[0] & MICROBLAZE_PVR0_USE_MMU_MASK)
 #define MICROBLAZE_PVR_USE_BTC(_pvr)                 (_pvr.pvr[0] & MICROBLAZE_PVR0_USE_BTC_MASK)
 #define MICROBLAZE_PVR_ENDIANNESS(_pvr)              (_pvr.pvr[0] & MICROBLAZE_PVR0_ENDIANNESS_MASK)
@@ -521,12 +509,16 @@ Returns the value of C_USE_MMU. Refer to the MicroBlaze Processor Reference Guid
 #define MICROBLAZE_PVR_MMU_PRIVILEGED_INSTR(_pvr)    ((_pvr.pvr[11] & MICROBLAZE_PVR11_MMU_PRIVILEGED_INSTR_MASK) >> 16)
 
 /* Protos */
+/**
+ *@endcond
+ */
 int microblaze_get_pvr (pvr_t *pvr);
 
 #ifdef __cplusplus
 }
 #endif
 #endif /* _PVR_H */
+
 /**
 * @} End of "addtogroup microblaze_pvr_macros".
 */
