@@ -1,42 +1,12 @@
 #   Copyright (c) 2017, Xilinx, Inc.
-#   All rights reserved.
-#
-#   Redistribution and use in source and binary forms, with or without
-#   modification, are permitted provided that the following conditions are met:
-#
-#   1.  Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#   2.  Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#   3.  Neither the name of the copyright holder nor the names of its
-#       contributors may be used to endorse or promote products derived from
-#       this software without specific prior written permission.
-#
-#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-#   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-#   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-#   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-#   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-#   OR BUSINESS INTERRUPTION). HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-#   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-#   OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-#   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#   SPDX-License-Identifier: BSD-3-Clause
 
-from pynq import DefaultIP
-from pynq import UnsupportedConfiguration
-from pynq import allocate
 import numpy
+from pynqutils.runtime.repr_dict import ReprDict
+from pynq import allocate
+from pynq import DefaultIP, UnsupportedConfiguration
 
 
-__author__ = 'Peter Ogden, Anurag Dubey'
-__copyright__ = 'Copyright 2017, Xilinx'
-__email__ = 'pynq_support@xilinx.com'
-
 
 MAX_C_SG_LENGTH_WIDTH = 26
 DMA_TYPE_TX = 1
@@ -56,6 +26,7 @@ class _SDMAChannel:
     through the AxiDMA class.
 
     """
+
     def __init__(self, mmio, max_size, width, tx_rx, dre, interrupt=None):
         """Initialize the simple DMA object.
 
@@ -96,9 +67,7 @@ class _SDMAChannel:
 
     @property
     def running(self):
-        """True if the DMA engine is currently running
-
-        """
+        """True if the DMA engine is currently running"""
         return self._mmio.read(self._offset + 4) & 0x01 == 0x00
 
     @property
@@ -112,14 +81,11 @@ class _SDMAChannel:
 
     @property
     def error(self):
-        """True if DMA engine is in an error state
-        """
+        """True if DMA engine is in an error state"""
         return self._mmio.read(self._offset + 4) & 0x70 != 0x0
 
     def start(self):
-        """Start the DMA engine if stopped
-
-        """
+        """Start the DMA engine if stopped"""
         if self._interrupt:
             self._mmio.write(self._offset, 0x1001)
         else:
@@ -129,9 +95,7 @@ class _SDMAChannel:
         self._first_transfer = True
 
     def stop(self):
-        """Stops the DMA channel and aborts the current transfer
-
-        """
+        """Stops the DMA channel and aborts the current transfer"""
         self._mmio.write(self._offset, 0x0000)
         while self.running:
             pass
@@ -169,70 +133,70 @@ class _SDMAChannel:
 
         """
         if not self.running:
-            raise RuntimeError('DMA channel not started')
+            raise RuntimeError("DMA channel not started")
         if not self.idle and not self._first_transfer:
-            raise RuntimeError('DMA channel not idle')
+            raise RuntimeError("DMA channel not idle")
         if nbytes == 0:
             nbytes = array.nbytes - start
         if nbytes > self._max_size:
-            raise ValueError('Transfer size is {} bytes, which exceeds '
-                             'the maximum DMA buffer size {}.'.format(
-                              nbytes, self._max_size))
+            raise ValueError(
+                "Transfer size is {} bytes, which exceeds "
+                "the maximum DMA buffer size {}.".format(nbytes, self._max_size)
+            )
 
-        if not self._dre and \
-                ((array.physical_address + start) % self._align) != 0:
-            raise RuntimeError('DMA does not support unaligned transfers; '
-                               'Starting address must be aligned to '
-                               '{} bytes.'.format(self._align))
+        if not self._dre and ((array.physical_address + start) % self._align) != 0:
+            raise RuntimeError(
+                "DMA does not support unaligned transfers; "
+                "Starting address must be aligned to "
+                "{} bytes.".format(self._align)
+            )
         if self._flush_before:
             array.flush()
         self.transferred = 0
         self._mmio.write(
-            self._offset + 0x18,
-            (array.physical_address + start) & 0xffffffff)
+            self._offset + 0x18, (array.physical_address + start) & 0xFFFFFFFF
+        )
         self._mmio.write(
-            self._offset + 0x1C,
-            ((array.physical_address + start) >> 32) & 0xffffffff)
+            self._offset + 0x1C, ((array.physical_address + start) >> 32) & 0xFFFFFFFF
+        )
         self._mmio.write(self._offset + 0x28, nbytes)
         self._active_buffer = array
         self._first_transfer = False
 
     def wait(self):
-        """Wait for the transfer to complete
-
-        """
+        """Wait for the transfer to complete"""
         if not self.running:
-            raise RuntimeError('DMA channel not started')
+            raise RuntimeError("DMA channel not started")
         while True:
             error = self._mmio.read(self._offset + 4)
             if self.error:
                 if error & 0x10:
-                    raise RuntimeError(
-                        'DMA Internal Error (transfer length 0?)')
+                    raise RuntimeError("DMA Internal Error (transfer length 0?)")
                 if error & 0x20:
                     raise RuntimeError(
-                        'DMA Slave Error (cannot access memory map interface)')
+                        "DMA Slave Error (cannot access memory map interface)"
+                    )
                 if error & 0x40:
-                    raise RuntimeError(
-                        'DMA Decode Error (invalid address)')
+                    raise RuntimeError("DMA Decode Error (invalid address)")
             if self.idle:
                 break
         if not self._flush_before:
             self._active_buffer.invalidate()
         self.transferred = self._mmio.read(self._offset + 0x28)
-
+        # Clean up buffer
+        self._active_buffer = None
+        
     async def wait_async(self):
-        """Wait for the transfer to complete
-
-        """
+        """Wait for the transfer to complete"""
         if not self.running:
-            raise RuntimeError('DMA channel not started')
+            raise RuntimeError("DMA channel not started")
         while not self.idle:
             await self._interrupt.wait()
         self._clear_interrupt()
         if not self._flush_before:
             self._active_buffer.invalidate()
         self.transferred = self._mmio.read(self._offset + 0x28)
+        self._active_buffer = None
 
 
 class _SGDMAChannel:
@@ -248,7 +212,8 @@ class _SGDMAChannel:
     through the AxiDMA class.
 
     """
-    def __init__(self, mmio, max_size, width, tx_rx, dre, interrupt=None):
+
+    def __init__(self, mmio, max_size, width, tx_rx, dre, interrupt=None, device=None):
         """Initialize the simple DMA object.
 
         Parameters
@@ -269,11 +234,13 @@ class _SGDMAChannel:
         """
         self._mmio = mmio
         self._interrupt = interrupt
+        self.device = device
         self._max_size = max_size
         self._active_buffer = None
         self._align = width
         self._tx_rx = tx_rx
         self._dre = dre
+        self._cyclic = False
 
         if tx_rx == DMA_TYPE_RX:
             self._offset = 0x30
@@ -291,9 +258,7 @@ class _SGDMAChannel:
 
     @property
     def running(self):
-        """True if the DMA engine is currently running
-
-        """
+        """True if the DMA engine is currently running"""
         return self._mmio.read(self._offset + 4) & 0x01 == 0x00
 
     @property
@@ -316,27 +281,32 @@ class _SGDMAChannel:
 
     @property
     def error(self):
-        """True if DMA engine is in an error state
-        """
+        """True if DMA engine is in an error state"""
         return self._mmio.read(self._offset + 4) & 0x770 != 0x0
 
     def start(self):
-        """Start the DMA engine if stopped
-
-        """
-        if self._interrupt:
-            self._mmio.write(self._offset, 0x1001)
+        """Start the DMA engine if stopped"""
+        if not self._cyclic:
+            if self._interrupt:
+                self._mmio.write(self._offset, 0x1001)
+            else:
+                self._mmio.write(self._offset, 0x0001)
         else:
-            self._mmio.write(self._offset, 0x0001)
+            if self._interrupt:
+                self._mmio.write(self._offset, 0x1011)
+            else:
+                self._mmio.write(self._offset, 0x0011)
         while not self.running:
             pass
         self._transfer_started = True
 
     def stop(self):
-        """Stops the DMA channel and aborts the current transfer
-
-        """
+        """Stops the DMA channel and aborts the current transfer"""
         self._mmio.write(self._offset, 0x0000)
+        # In Cyclic BD mode the DMA requires a reset if stopped
+        if self._cyclic:
+            self._mmio.write(0x0, 0x0004)
+            self._mmio.write(0x0, 0x0000)
         while self.running:
             pass
         self._transfer_started = False
@@ -344,7 +314,7 @@ class _SGDMAChannel:
     def _clear_interrupt(self):
         self._mmio.write(self._offset + 4, 0x1000)
 
-    def transfer(self, array, start=0, nbytes=0):
+    def transfer(self, array, start=0, nbytes=0, cyclic=False):
         """Transfer memory with the DMA
 
         Transfer must only be called when the channel is halted
@@ -362,6 +332,12 @@ class _SGDMAChannel:
         For example, if memory map data width = 32, data is aligned if it is
         located at word offsets (32-bit offset), that is, 0x0, 0x4, 0x8, 0xC,
         and so forth.
+        
+        Cyclic Buffer Descriptor (BD) mode allows the DMA to loop through the 
+        buffer descriptors without user intervention. As the DMA cycles through 
+        the BDs indefinitely, the wait() function is not valid in this mode. 
+        Instead, use the stop() function to terminate DMA operation. This mode 
+        is only valid for the sendchannel.
 
         Parameters
         ----------
@@ -371,19 +347,27 @@ class _SGDMAChannel:
              Offset into array to start. Default is 0.
         nbytes : int
              Number of bytes to transfer. Default is 0.
+        cyclic : bool
+             Enable cyclic BD mode. Default is False.
 
         """
 
         if not self.halted:
-            raise RuntimeError('DMA channel not halted')
+            raise RuntimeError("DMA channel not halted")
         if nbytes == 0:
             nbytes = array.nbytes - start
-        if not self._dre and \
-                ((array.physical_address + start) % self._align) != 0:
-            raise RuntimeError('DMA does not support unaligned transfers; '
-                               'Starting address must be aligned to '
-                               '{} bytes.'.format(self._align))
+        if not self._dre and ((array.physical_address + start) % self._align) != 0:
+            raise RuntimeError(
+                "DMA does not support unaligned transfers; "
+                "Starting address must be aligned to "
+                "{} bytes.".format(self._align)
+            )
+            
+        self._cyclic = cyclic
 
+        if self._cyclic and (self._tx_rx != DMA_TYPE_TX):
+            raise RuntimeError('Cyclic BD mode only valid in sendchannel')
+        
         # Figure out largest possible block size, and no. of descriptors needed
         remain = nbytes
         blk_size = self._max_size - (self._max_size % self._align)
@@ -391,14 +375,13 @@ class _SGDMAChannel:
         # We need to always have at least two descriptors!
         if blk_size > remain:
             blk_size = int(remain / 2)
-            blk_size -= (blk_size % self._align)
+            blk_size -= blk_size % self._align
 
         self._num_descr = int((remain + (blk_size - 1)) / blk_size)
 
         # Zero-Allocate buffer for descriptors: uint32[_num_descr][16]
         # Descriptor is only 52 bytes but each one has to be 64-byte aligned!
-        self._descr = allocate(
-            shape=(self._num_descr, 16), dtype=numpy.uint32)
+        self._descr = allocate(shape=(self._num_descr, 16), dtype=numpy.uint32, target=self.device)
 
         # Idle DMA engine
         self.stop()
@@ -406,12 +389,20 @@ class _SGDMAChannel:
         # Fill out descriptors
         for i in range(0, self._num_descr):
             # Next descriptor (64-bit)
-            self._descr[i, 0] = \
-                (self._descr.physical_address +
-                 (((i + 1) % self._num_descr) * 16 * 4)) & 0xffffffff
-            self._descr[i, 1] = \
-                (self._descr.physical_address +
-                 (((i + 1) % self._num_descr) * 16 * 4) >> 32) & 0xffffffff
+            if self._cyclic and (i == (self._num_descr - 1)):
+                # In cyclic BD mode the last descriptor points back the the first
+                self._descr[i, 0] = (
+                self._descr.physical_address) & 0xffffffff
+                self._descr[i, 1] = (
+                self._descr.physical_address >> 32) & 0xffffffff
+            else:
+                self._descr[i, 0] = (
+                self._descr.physical_address + (((i + 1) % self._num_descr) * 16 * 4)
+                ) & 0xFFFFFFFF
+                self._descr[i, 1] = (
+                self._descr.physical_address + (((i + 1) % self._num_descr) * 16 * 4)
+                >> 32
+                ) & 0xFFFFFFFF
 
             # Buffer length
             if remain > blk_size:
@@ -423,18 +414,18 @@ class _SGDMAChannel:
             remain -= d_len
 
             # Buffer address (64-bit)
-            self._descr[i, 2] = \
-                (array.physical_address + (i * blk_size)) & 0xffffffff
-            self._descr[i, 3] = \
-                ((array.physical_address + (i * blk_size)) >> 32) & 0xffffffff
+            self._descr[i, 2] = (array.physical_address + (i * blk_size)) & 0xFFFFFFFF
+            self._descr[i, 3] = (
+                (array.physical_address + start + (i * blk_size)) >> 32
+            ) & 0xFFFFFFFF
 
             # First block
             if i == 0:
-                self._descr[i, 6] |= (1 << 27)
+                self._descr[i, 6] |= 1 << 27
 
             # Last Block
             if remain == 0:
-                self._descr[i, 6] |= (1 << 26)
+                self._descr[i, 6] |= 1 << 26
 
         if self._flush_before:
             array.flush()
@@ -443,10 +434,10 @@ class _SGDMAChannel:
         self._descr.flush()
 
         # Write first desc
-        self._mmio.write(self._offset + 0x08,
-                         self._descr.physical_address & 0xffffffff)
-        self._mmio.write(self._offset + 0x0c,
-                         (self._descr.physical_address >> 32) & 0xffffffff)
+        self._mmio.write(self._offset + 0x08, self._descr.physical_address & 0xFFFFFFFF)
+        self._mmio.write(
+            self._offset + 0x0C, (self._descr.physical_address >> 32) & 0xFFFFFFFF
+        )
 
         self._active_buffer = array
 
@@ -455,45 +446,59 @@ class _SGDMAChannel:
         self.start()
 
         # Writing last desc triggers the descriptor fetches
-        self._mmio.write(
-            self._offset + 0x10,
-            (self._descr.physical_address +
-             ((self._num_descr - 1) * 16 * 4)) & 0xffffffff)
-        self._mmio.write(
-            self._offset + 0x14,
-            ((self._descr.physical_address +
-              ((self._num_descr - 1) * 16 * 4)) >> 32) & 0xffffffff)
+        if self._cyclic:
+            # In cyclic BD mode the tail descriptor register must be programmed
+            # with a value which is not part of the BD chain.
+            self._mmio.write(
+                    self._offset + 0x10, 
+                    (self._descr.physical_address + 
+                        ((self._num_descr) * 16 * 4)) & 0xffffffff)
+            self._mmio.write(
+                    self._offset + 0x14, 
+                    ((self._descr.physical_address +  
+                        ((self._num_descr) * 16 * 4)) >> 32) & 0xffffffff)
+        else:
+            self._mmio.write(
+                    self._offset + 0x10, 
+                    (self._descr.physical_address + 
+                        ((self._num_descr - 1) * 16 * 4)) & 0xffffffff)
+            self._mmio.write(
+                    self._offset + 0x14, 
+                    ((self._descr.physical_address +  
+                        ((self._num_descr - 1) * 16 * 4)) >> 32) & 0xffffffff)
 
     def wait(self):
-        """Wait for the transfer to complete
-
-        """
+        """Wait for the transfer to complete"""
+        # wait not valid in cyclic BD mode.
+        if self._cyclic:
+            raise RuntimeError('Cannot wait in cyclic BD mode')
         if not self._transfer_started:
-            raise RuntimeError('DMA transfer not started')
+            raise RuntimeError("DMA transfer not started")
         while True:
             if self.error:
                 error = self._mmio.read(self._offset + 4)
                 if error & 0x10:
-                    raise RuntimeError(
-                        'DMA Internal Error (transfer length 0?)')
+                    raise RuntimeError("DMA Internal Error (transfer length 0?)")
                 if error & 0x20:
                     raise RuntimeError(
-                        'DMA Slave Error (cannot access memory map interface)')
+                        "DMA Slave Error (cannot access memory map interface)"
+                    )
                 if error & 0x40:
-                    raise RuntimeError(
-                        'DMA Decode Error (invalid address)')
+                    raise RuntimeError("DMA Decode Error (invalid address)")
                 if error & 0x100:
                     raise RuntimeError(
-                        'Scatter-Gather Internal Error '
-                        '(re-used completed descriptor)')
+                        "Scatter-Gather Internal Error "
+                        "(re-used completed descriptor)"
+                    )
                 if error & 0x200:
                     raise RuntimeError(
-                        'Scatter-Gather Slave Error '
-                        '(cannot access memory map interface)')
+                        "Scatter-Gather Slave Error "
+                        "(cannot access memory map interface)"
+                    )
                 if error & 0x400:
                     raise RuntimeError(
-                        'Scatter-Gather Decode Error '
-                        '(invalid descriptor address)')
+                        "Scatter-Gather Decode Error " "(invalid descriptor address)"
+                    )
             if self.idle or self.halted:
                 break
         if not self._flush_before:
@@ -505,8 +510,8 @@ class _SGDMAChannel:
         for i in range(0, self._num_descr):
             # XXX if micro mode, this doesn't apply. Count descriptors instead.
             if self._descr[i, 7] & 0x30000000:
-                raise RuntimeError('DMA Error in descriptor')
-            self.transferred += self._descr[i, 7] & 0x03ffffff
+                raise RuntimeError("DMA Error in descriptor")
+            self.transferred += self._descr[i, 7] & 0x03FFFFFF
 
         # Ensure engine is idled
         self.stop()
@@ -514,13 +519,16 @@ class _SGDMAChannel:
         # Clean up descriptor buffer
         self._descr.close()
         self._descr = None
+        # Clean up buffer
+        self._active_buffer = None
 
     async def wait_async(self):
-        """Wait for the transfer to complete
-
-        """
+        """Wait for the transfer to complete"""
+        # wait not valid in cyclic BD mode.
+        if self._cyclic:
+            raise RuntimeError('Cannot wait in cyclic BD mode')
         if not self._transfer_started:
-            raise RuntimeError('DMA transfer not started')
+            raise RuntimeError("DMA transfer not started")
         while not (self.idle or self.halted):
             await self._interrupt.wait()
         self._clear_interrupt()
@@ -533,8 +541,8 @@ class _SGDMAChannel:
         for i in range(0, self._num_descr):
             # XXX if micro mode, this doesn't apply.  Count descriptors instead.
             if self._descr[i, 7] & 0x30000000:
-                raise RuntimeError('DMA Error in descriptor')
-            self.transferred += self._descr[i, 7] & 0x03ffffff
+                raise RuntimeError("DMA Error in descriptor")
+            self.transferred += self._descr[i, 7] & 0x03FFFFFF
 
         # Ensure engine is idled
         self.stop()
@@ -543,6 +551,8 @@ class _SGDMAChannel:
         self._descr.close()
         self._descr = None
 
+        self._active_buffer = None
+
 
 class DMA(DefaultIP):
     """Class for Interacting with the AXI Simple DMA Engine
@@ -569,6 +579,7 @@ class DMA(DefaultIP):
         The maximum DMA transfer length.
 
     """
+
     def __init__(self, description, *args, **kwargs):
         """Create an instance of the DMA Driver
 
@@ -581,34 +592,45 @@ class DMA(DefaultIP):
             The entry in the IP dict describing the DMA engine
 
         """
-        if type(description) is not dict or args or kwargs:
-            raise RuntimeError('You appear to want the old DMA driver which '
-                               'has been deprecated and moved to '
-                               'pynq.lib.deprecated')
+        if type(description) not in [dict, ReprDict] or args or kwargs:
+            raise RuntimeError(
+                "You appear to want the old DMA driver which "
+                "has been deprecated and moved to "
+                "pynq.lib.deprecated"
+            )
         super().__init__(description=description)
         self.description = description
 
-        if 'parameters' not in description:
-            raise RuntimeError('Unable to get parameters from description; '
-                               'Users must use *.hwh files for overlays.')
+        if "device" in description:
+            self.device = description["device"]
+        else:
+            raise RuntimeError("Device not specified in description")
 
-        if 'c_micro_dma' in description['parameters']:
-            self._micro = bool(int(description['parameters']['c_micro_dma']))
+        if "parameters" not in description:
+            raise RuntimeError(
+                "Unable to get parameters from description; "
+                "Users must use *.hwh files for overlays."
+            )
+
+        if "c_micro_dma" in description["parameters"]:
+            self._micro = bool(int(description["parameters"]["c_micro_dma"]))
         else:
             self._micro = False
 
-        if 'c_include_sg' in description['parameters']:
-            self._sg = bool(int(description['parameters']['c_include_sg']))
+        if "c_include_sg" in description["parameters"]:
+            self._sg = bool(int(description["parameters"]["c_include_sg"]))
         else:
             self._sg = False
 
         if self._micro and self._sg:
             raise UnsupportedConfiguration(
-                'Micro and Scatter-gather modes not supported simultaneously.')
+                "Micro and Scatter-gather modes not supported simultaneously."
+            )
 
-        if 'c_sg_length_width' in description['parameters']:
+        if "c_sg_length_width" in description["parameters"]:
             self.buffer_max_size = 1 << int(
-                description['parameters']['c_sg_length_width'])
+                description["parameters"]["c_sg_length_width"]
+            )
         else:
             self.buffer_max_size = 1 << MAX_C_SG_LENGTH_WIDTH
 
@@ -627,32 +649,36 @@ class DMA(DefaultIP):
         and (2) whether SG mode is used, we will create the transmit channel.
 
         """
-        if 'c_include_mm2s' in self.description['parameters'] and \
-                bool(int(self.description['parameters']['c_include_mm2s'])):
-            if 'c_include_mm2s_dre' in self.description['parameters']:
-                dre = bool(int(
-                    self.description['parameters']['c_include_mm2s_dre']))
+        if "c_include_mm2s" in self.description["parameters"] and bool(
+            int(self.description["parameters"]["c_include_mm2s"])
+        ):
+            if "c_include_mm2s_dre" in self.description["parameters"]:
+                dre = bool(int(self.description["parameters"]["c_include_mm2s_dre"]))
             else:
                 dre = False
 
-            data_width = int(
-                self.description['parameters']['c_m_axi_mm2s_data_width']) >> 3
+            data_width = (
+                int(self.description["parameters"]["c_m_axi_mm2s_data_width"]) >> 3
+            )
 
             if self._micro:
                 max_size = data_width * int(
-                    self.description['parameters']['c_mm2s_burst_size'])
+                    self.description["parameters"]["c_mm2s_burst_size"]
+                )
             else:
                 max_size = self.buffer_max_size
 
-            if 'mm2s_introut' in self.description['interrupts']:
+            if "mm2s_introut" in self.description["interrupts"]:
                 if self._sg:
                     self.sendchannel = _SGDMAChannel(
                         self.mmio,
                         max_size,
-                        6,
+                        data_width,
                         DMA_TYPE_TX,
                         dre,
-                        self.mm2s_introut)
+                        self.mm2s_introut,
+                        device=self.device,
+                    )
                 else:
                     self.sendchannel = _SDMAChannel(
                         self.mmio,
@@ -660,22 +686,17 @@ class DMA(DefaultIP):
                         data_width,
                         DMA_TYPE_TX,
                         dre,
-                        self.mm2s_introut)
+                        self.mm2s_introut,
+                    )
             else:
                 if self._sg:
                     self.sendchannel = _SGDMAChannel(
-                        self.mmio,
-                        max_size,
-                        6,
-                        DMA_TYPE_TX,
-                        dre)
+                        self.mmio, max_size, data_width, DMA_TYPE_TX, dre, device=self.device
+                    )
                 else:
                     self.sendchannel = _SDMAChannel(
-                        self.mmio,
-                        max_size,
-                        data_width,
-                        DMA_TYPE_TX,
-                        dre)
+                        self.mmio, max_size, data_width, DMA_TYPE_TX, dre
+                    )
 
     def set_up_rx_channel(self):
         """Set up the receive channel.
@@ -685,32 +706,36 @@ class DMA(DefaultIP):
         and (2) whether SG mode is used, we will create the receive channel.
 
         """
-        if 'c_include_s2mm' in self.description['parameters'] and \
-                bool(int(self.description['parameters']['c_include_s2mm'])):
-            if 'c_include_s2mm_dre' in self.description['parameters']:
-                dre = bool(int(
-                    self.description['parameters']['c_include_s2mm_dre']))
+        if "c_include_s2mm" in self.description["parameters"] and bool(
+            int(self.description["parameters"]["c_include_s2mm"])
+        ):
+            if "c_include_s2mm_dre" in self.description["parameters"]:
+                dre = bool(int(self.description["parameters"]["c_include_s2mm_dre"]))
             else:
                 dre = False
 
-            data_width = int(
-                self.description['parameters']['c_m_axi_s2mm_data_width']) >> 3
+            data_width = (
+                int(self.description["parameters"]["c_m_axi_s2mm_data_width"]) >> 3
+            )
 
             if self._micro:
                 max_size = data_width * int(
-                    self.description['parameters']['c_s2mm_burst_size'])
+                    self.description["parameters"]["c_s2mm_burst_size"]
+                )
             else:
                 max_size = self.buffer_max_size
 
-            if 's2mm_introut' in self.description['interrupts']:
+            if "s2mm_introut" in self.description["interrupts"]:
                 if self._sg:
                     self.recvchannel = _SGDMAChannel(
                         self.mmio,
                         max_size,
-                        6,
+                        data_width,
                         DMA_TYPE_RX,
                         dre,
-                        self.s2mm_introut)
+                        self.s2mm_introut,
+                        device=self.device,
+                    )
                 else:
                     self.recvchannel = _SDMAChannel(
                         self.mmio,
@@ -718,21 +743,17 @@ class DMA(DefaultIP):
                         data_width,
                         DMA_TYPE_RX,
                         dre,
-                        self.s2mm_introut)
+                        self.s2mm_introut,
+                    )
             else:
                 if self._sg:
                     self.recvchannel = _SGDMAChannel(
-                        self.mmio,
-                        max_size,
-                        6,
-                        DMA_TYPE_RX,
-                        dre)
+                        self.mmio, max_size, data_width, DMA_TYPE_RX, dre, device=self.device
+                    )
                 else:
                     self.recvchannel = _SDMAChannel(
-                        self.mmio,
-                        max_size,
-                        data_width,
-                        DMA_TYPE_RX,
-                        dre)
+                        self.mmio, max_size, data_width, DMA_TYPE_RX, dre
+                    )
+
+    bindto = ["xilinx.com:ip:axi_dma:7.1"]
 
-    bindto = ['xilinx.com:ip:axi_dma:7.1']
