@@ -57,6 +57,7 @@
 #define XPAR_LCP_AR_MB_D_LMB_PROTOCOL 0
 #define XPAR_LCP_AR_MB_ECC_USE_CE_EXCEPTION 0
 #define XPAR_LCP_AR_MB_EDGE_IS_POSITIVE 1
+#define XPAR_LCP_AR_MB_ENABLE_CONVERSION 1
 #define XPAR_LCP_AR_MB_ENABLE_DISCRETE_PORTS 0
 #define XPAR_LCP_AR_MB_ENDIANNESS 1
 #define XPAR_LCP_AR_MB_FAULT_TOLERANT 0
@@ -166,6 +167,7 @@
 #define XPAR_LCP_AR_MB_NUM_SYNC_FF_DBG_TRACE_CLK 2
 #define XPAR_LCP_AR_MB_OPCODE_0X0_ILLEGAL 0
 #define XPAR_LCP_AR_MB_OPTIMIZATION 0
+#define XPAR_LCP_AR_MB_PART xc7z020clg400-1
 #define XPAR_LCP_AR_MB_PC_WIDTH 32
 #define XPAR_LCP_AR_MB_PIADDR_SIZE 32
 #define XPAR_LCP_AR_MB_PVR 0
@@ -211,6 +213,7 @@
 #define XPAR_LCP_AR_MB_S15_AXIS_DATA_WIDTH 32
 #define XPAR_LCP_AR_MB_S15_AXIS_PROTOCOL GENERIC
 #define XPAR_LCP_AR_MB_SCO 0
+#define XPAR_LCP_AR_MB_TEMPORAL_DEPTH 0
 #define XPAR_LCP_AR_MB_TRACE 0
 #define XPAR_LCP_AR_MB_UNALIGNED_EXCEPTIONS 0
 #define XPAR_LCP_AR_MB_USE_BARREL 0
@@ -283,6 +286,7 @@
 #define XPAR_MICROBLAZE_D_LMB_PROTOCOL 0
 #define XPAR_MICROBLAZE_ECC_USE_CE_EXCEPTION 0
 #define XPAR_MICROBLAZE_EDGE_IS_POSITIVE 1
+#define XPAR_MICROBLAZE_ENABLE_CONVERSION 1
 #define XPAR_MICROBLAZE_ENABLE_DISCRETE_PORTS 0
 #define XPAR_MICROBLAZE_ENDIANNESS 1
 #define XPAR_MICROBLAZE_FAULT_TOLERANT 0
@@ -392,6 +396,7 @@
 #define XPAR_MICROBLAZE_NUM_SYNC_FF_DBG_TRACE_CLK 2
 #define XPAR_MICROBLAZE_OPCODE_0X0_ILLEGAL 0
 #define XPAR_MICROBLAZE_OPTIMIZATION 0
+#define XPAR_MICROBLAZE_PART xc7z020clg400-1
 #define XPAR_MICROBLAZE_PC_WIDTH 32
 #define XPAR_MICROBLAZE_PIADDR_SIZE 32
 #define XPAR_MICROBLAZE_PVR 0
@@ -437,6 +442,7 @@
 #define XPAR_MICROBLAZE_S15_AXIS_DATA_WIDTH 32
 #define XPAR_MICROBLAZE_S15_AXIS_PROTOCOL GENERIC
 #define XPAR_MICROBLAZE_SCO 0
+#define XPAR_MICROBLAZE_TEMPORAL_DEPTH 0
 #define XPAR_MICROBLAZE_TRACE 0
 #define XPAR_MICROBLAZE_UNALIGNED_EXCEPTIONS 0
 #define XPAR_MICROBLAZE_USE_BARREL 0
