@@ -1,6 +1,9 @@
 // ==============================================================
-// Vitis HLS - High-Level Synthesis from C, C++ and OpenCL v2020.2 (64-bit)
-// Copyright 1986-2020 Xilinx, Inc. All Rights Reserved.
+// Vitis HLS - High-Level Synthesis from C, C++ and OpenCL v2024.1 (64-bit)
+// Tool Version Limit: 2024.05
+// Copyright 1986-2022 Xilinx, Inc. All Rights Reserved.
+// Copyright 2022-2024 Advanced Micro Devices, Inc. All Rights Reserved.
+// 
 // ==============================================================
 #ifndef XTRACE_CNTRL_64_H
 #define XTRACE_CNTRL_64_H
@@ -37,8 +40,12 @@ typedef uint32_t u32;
 typedef uint64_t u64;
 #else
 typedef struct {
+#ifdef SDT
+    char *Name;
+#else
     u16 DeviceId;
-    u32 Trace_cntrl_BaseAddress;
+#endif
+    u64 Trace_cntrl_BaseAddress;
 } XTrace_cntrl_64_Config;
 #endif
 
@@ -72,8 +79,13 @@ typedef u32 word_type;
 
 /************************** Function Prototypes *****************************/
 #ifndef __linux__
+#ifdef SDT
+int XTrace_cntrl_64_Initialize(XTrace_cntrl_64 *InstancePtr, UINTPTR BaseAddress);
+XTrace_cntrl_64_Config* XTrace_cntrl_64_LookupConfig(UINTPTR BaseAddress);
+#else
 int XTrace_cntrl_64_Initialize(XTrace_cntrl_64 *InstancePtr, u16 DeviceId);
 XTrace_cntrl_64_Config* XTrace_cntrl_64_LookupConfig(u16 DeviceId);
+#endif
 int XTrace_cntrl_64_CfgInitialize(XTrace_cntrl_64 *InstancePtr, XTrace_cntrl_64_Config *ConfigPtr);
 #else
 int XTrace_cntrl_64_Initialize(XTrace_cntrl_64 *InstancePtr, const char* InstanceName);
