@@ -57,6 +57,7 @@
 #define XPAR_IOP_PMODA_MB_D_LMB_PROTOCOL 0
 #define XPAR_IOP_PMODA_MB_ECC_USE_CE_EXCEPTION 0
 #define XPAR_IOP_PMODA_MB_EDGE_IS_POSITIVE 1
+#define XPAR_IOP_PMODA_MB_ENABLE_CONVERSION 1
 #define XPAR_IOP_PMODA_MB_ENABLE_DISCRETE_PORTS 0
 #define XPAR_IOP_PMODA_MB_ENDIANNESS 1
 #define XPAR_IOP_PMODA_MB_FAULT_TOLERANT 0
@@ -166,6 +167,7 @@
 #define XPAR_IOP_PMODA_MB_NUM_SYNC_FF_DBG_TRACE_CLK 2
 #define XPAR_IOP_PMODA_MB_OPCODE_0X0_ILLEGAL 0
 #define XPAR_IOP_PMODA_MB_OPTIMIZATION 0
+#define XPAR_IOP_PMODA_MB_PART xc7z020clg400-1
 #define XPAR_IOP_PMODA_MB_PC_WIDTH 32
 #define XPAR_IOP_PMODA_MB_PIADDR_SIZE 32
 #define XPAR_IOP_PMODA_MB_PVR 0
@@ -211,6 +213,7 @@
 #define XPAR_IOP_PMODA_MB_S15_AXIS_DATA_WIDTH 32
 #define XPAR_IOP_PMODA_MB_S15_AXIS_PROTOCOL GENERIC
 #define XPAR_IOP_PMODA_MB_SCO 0
+#define XPAR_IOP_PMODA_MB_TEMPORAL_DEPTH 0
 #define XPAR_IOP_PMODA_MB_TRACE 0
 #define XPAR_IOP_PMODA_MB_UNALIGNED_EXCEPTIONS 0
 #define XPAR_IOP_PMODA_MB_USE_BARREL 0
@@ -283,6 +286,7 @@
 #define XPAR_MICROBLAZE_D_LMB_PROTOCOL 0
 #define XPAR_MICROBLAZE_ECC_USE_CE_EXCEPTION 0
 #define XPAR_MICROBLAZE_EDGE_IS_POSITIVE 1
+#define XPAR_MICROBLAZE_ENABLE_CONVERSION 1
 #define XPAR_MICROBLAZE_ENABLE_DISCRETE_PORTS 0
 #define XPAR_MICROBLAZE_ENDIANNESS 1
 #define XPAR_MICROBLAZE_FAULT_TOLERANT 0
@@ -392,6 +396,7 @@
 #define XPAR_MICROBLAZE_NUM_SYNC_FF_DBG_TRACE_CLK 2
 #define XPAR_MICROBLAZE_OPCODE_0X0_ILLEGAL 0
 #define XPAR_MICROBLAZE_OPTIMIZATION 0
+#define XPAR_MICROBLAZE_PART xc7z020clg400-1
 #define XPAR_MICROBLAZE_PC_WIDTH 32
 #define XPAR_MICROBLAZE_PIADDR_SIZE 32
 #define XPAR_MICROBLAZE_PVR 0
@@ -437,6 +442,7 @@
 #define XPAR_MICROBLAZE_S15_AXIS_DATA_WIDTH 32
 #define XPAR_MICROBLAZE_S15_AXIS_PROTOCOL GENERIC
 #define XPAR_MICROBLAZE_SCO 0
+#define XPAR_MICROBLAZE_TEMPORAL_DEPTH 0
 #define XPAR_MICROBLAZE_TRACE 0
 #define XPAR_MICROBLAZE_UNALIGNED_EXCEPTIONS 0
 #define XPAR_MICROBLAZE_USE_BARREL 0
@@ -479,11 +485,16 @@
  
 /******************************************************************/
 
-/* Definitions for peripheral ADDRESS_REMAP_0 */
+/* Peripheral Definitions for peripheral ADDRESS_REMAP_0 */
 #define XPAR_ADDRESS_REMAP_0_S_AXI_IN_BASEADDR 0x20000000
 #define XPAR_ADDRESS_REMAP_0_S_AXI_IN_HIGHADDR 0x3FFFFFFF
 
 
+/******************************************************************/
+
+
+
+
 /******************************************************************/
 
 /* Definitions for driver GPIO */
@@ -548,6 +559,7 @@
 #define XPAR_IOP_PMODA_INTC_HAS_FAST 0
 #define XPAR_IOP_PMODA_INTC_IVAR_RESET_VALUE 0x0000000000000010
 #define XPAR_IOP_PMODA_INTC_NUM_INTR_INPUTS 3
+#define XPAR_IOP_PMODA_INTC_NUM_SW_INTR 0
 #define XPAR_IOP_PMODA_INTC_ADDR_WIDTH 32
 
 
@@ -574,6 +586,7 @@
 #define XPAR_INTC_0_HAS_FAST 0U
 #define XPAR_INTC_0_IVAR_RESET_VALUE 0x0000000000000010U
 #define XPAR_INTC_0_NUM_INTR_INPUTS 3U
+#define XPAR_INTC_0_NUM_SW_INTR 0U
 #define XPAR_INTC_0_ADDR_WIDTH 32U
 #define XPAR_INTC_0_INTC_TYPE 0U
 
@@ -643,8 +656,8 @@
 #define XPAR_IOP_PMODA_SPI_DEVICE_ID 0U
 #define XPAR_IOP_PMODA_SPI_BASEADDR 0x44A10000U
 #define XPAR_IOP_PMODA_SPI_HIGHADDR 0x44A1FFFFU
-#define XPAR_IOP_PMODA_SPI_FIFO_DEPTH 16U
 #define XPAR_IOP_PMODA_SPI_FIFO_EXIST 1U
+#define XPAR_IOP_PMODA_SPI_FIFO_DEPTH 16U
 #define XPAR_IOP_PMODA_SPI_SPI_SLAVE_ONLY 0U
 #define XPAR_IOP_PMODA_SPI_NUM_SS_BITS 1U
 #define XPAR_IOP_PMODA_SPI_NUM_TRANSFER_BITS 8U
@@ -658,8 +671,8 @@
 #define XPAR_SPI_0_DEVICE_ID 0U
 #define XPAR_SPI_0_BASEADDR 0x44A10000U
 #define XPAR_SPI_0_HIGHADDR 0x44A1FFFFU
-#define XPAR_SPI_0_FIFO_DEPTH 16U
 #define XPAR_SPI_0_FIFO_EXIST 1U
+#define XPAR_SPI_0_FIFO_DEPTH 16U
 #define XPAR_SPI_0_SPI_SLAVE_ONLY 0U
 #define XPAR_SPI_0_NUM_SS_BITS 1U
 #define XPAR_SPI_0_NUM_TRANSFER_BITS 8U
