@@ -1,53 +1,24 @@
 #   Copyright (c) 2016, Xilinx, Inc.
-#   All rights reserved.
-#
-#   Redistribution and use in source and binary forms, with or without
-#   modification, are permitted provided that the following conditions are met:
-#
-#   1.  Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#   2.  Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#   3.  Neither the name of the copyright holder nor the names of its
-#       contributors may be used to endorse or promote products derived from
-#       this software without specific prior written permission.
-#
-#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-#   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-#   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-#   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-#   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-#   OR BUSINESS INTERRUPTION). HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-#   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-#   OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-#   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#   SPDX-License-Identifier: BSD-3-Clause
 
-__author__ = "Peter Ogden"
-__copyright__ = "Copyright 2017, Xilinx"
-__email__ = "ogden@xilinx.com"
 
-import pycparser
-import struct
+import collections
 import functools
 import itertools
-import collections
 import math
-import re
 import os
-from pycparser import c_ast
-from pycparser import c_generator
-from pycparser.plyparser import ParseError
+import re
+import struct
 from copy import deepcopy
-from pynq.ps import ZU_ARCH, CPU_ARCH, ZYNQ_ARCH
-from .compile import preprocess
-from .streams import SimpleMBStream
-from .streams import InterruptMBStream
+
+import pycparser
+from pycparser import c_ast, c_generator
+from pycparser.plyparser import ParseError
+
+from pynq.ps import CPU_ARCH, ZU_ARCH, ZYNQ_ARCH
 from . import MicroblazeProgram
+from .compile import preprocess
+from .streams import InterruptMBStream, SimpleMBStream
 
 # Use a global parser and generator
 _parser = pycparser.CParser()
@@ -65,10 +36,11 @@ else:
 # Each class is responsible for one particular type of C
 # types
 class PrimitiveWrapper:
-    """ Wrapper for C primitives that can be represented by
+    """Wrapper for C primitives that can be represented by
     a single Struct string.
 
     """
+
     def __init__(self, struct_string, type_):
         self._struct = struct.Struct(struct_string)
         self.typedefname = None
@@ -96,15 +68,16 @@ class PrimitiveWrapper:
 
 
 class VoidPointerWrapper:
-    """ Wrapper for a void* pointer that will refer to a
+    """Wrapper for a void* pointer that will refer to a
     physically contiguous chunk of memory.
 
     """
+
     def __init__(self, type_):
         self._type = type_
         self.typedefname = None
         self.blocks = False
-        self._ptrstruct = struct.Struct('I')
+        self._ptrstruct = struct.Struct("I")
 
     def param_encode(self, old_val):
         return self._ptrstruct.pack(old_val.physical_address)
@@ -117,30 +90,43 @@ class VoidPointerWrapper:
 
     def pre_argument(self, name):
         commands = []
-        commands.append(_generate_decl(
-            name + '_int',
-            c_ast.TypeDecl(name + '_int', [],
-                           c_ast.IdentifierType(['unsigned', 'int']))))
-        commands.append(_generate_read(name +'_int'))
-        commands.append(c_ast.Assignment(
-            '|=',
-            c_ast.ID(name + '_int'),
-            c_ast.Constant('int', PTR_OFFSET)))
         commands.append(
-            c_ast.Decl(name, [], [], [],
-                       c_ast.PtrDecl(
-                            [], c_ast.TypeDecl(name, [],
-                                               c_ast.IdentifierType(['void'])),
-                       ),
-                       c_ast.Cast(
-                            c_ast.Typename(
-                                 None, [], c_ast.PtrDecl(
-                                     [], c_ast.TypeDecl(
-                                          None, [],
-                                          c_ast.IdentifierType(['void'])))),
-                            c_ast.ID(name + '_int')),
-                       []
-                       ))
+            _generate_decl(
+                name + "_int",
+                c_ast.TypeDecl(
+                    name + "_int", [], c_ast.IdentifierType(["unsigned", "int"])
+                ),
+            )
+        )
+        commands.append(_generate_read(name + "_int"))
+        commands.append(
+            c_ast.Assignment(
+                "|=", c_ast.ID(name + "_int"), c_ast.Constant("int", PTR_OFFSET)
+            )
+        )
+        commands.append(
+            c_ast.Decl(
+                name,
+                [],
+                [],
+                [],
+                c_ast.PtrDecl(
+                    [],
+                    c_ast.TypeDecl(name, [], c_ast.IdentifierType(["void"])),
+                ),
+                c_ast.Cast(
+                    c_ast.Typename(
+                        None,
+                        [],
+                        c_ast.PtrDecl(
+                            [], c_ast.TypeDecl(None, [], c_ast.IdentifierType(["void"]))
+                        ),
+                    ),
+                    c_ast.ID(name + "_int"),
+                ),
+                [],
+            )
+        )
         return commands
 
     def post_argument(self, name):
@@ -148,12 +134,13 @@ class VoidPointerWrapper:
 
 
 class ConstPointerWrapper:
-    """ Wrapper for const T pointers, transfers data in only
+    """Wrapper for const T pointers, transfers data in only
     one direction.
 
     """
+
     def __init__(self, type_, struct_string):
-        self._lenstruct = struct.Struct('h')
+        self._lenstruct = struct.Struct("h")
         self._struct_string = struct_string
         self.typedefname = None
         self.blocks = False
@@ -173,13 +160,14 @@ class ConstPointerWrapper:
         commands = []
         commands.append(
             _generate_decl(
-                name + '_len',
-                c_ast.TypeDecl(name + '_len', [],
-                               c_ast.IdentifierType(['unsigned', 'short']))))
-        commands.append(_generate_read(name + '_len'))
-        commands.append(_generate_arraydecl(name,
-                                            self._type,
-                                            c_ast.ID(name + '_len')))
+                name + "_len",
+                c_ast.TypeDecl(
+                    name + "_len", [], c_ast.IdentifierType(["unsigned", "short"])
+                ),
+            )
+        )
+        commands.append(_generate_read(name + "_len"))
+        commands.append(_generate_arraydecl(name, self._type, c_ast.ID(name + "_len")))
         commands.append(_generate_read(name, address=False))
         return commands
 
@@ -188,26 +176,32 @@ class ConstPointerWrapper:
 
 
 class ConstCharPointerWrapper(ConstPointerWrapper):
-    """ Wrapper for const char*s which accepts Python strings and
+    """Wrapper for const char*s which accepts Python strings and
     makes sure they are NULL-terminated
 
     """
+
     def __init__(self, type_):
-        super().__init__(type_, 'b')
+        super().__init__(type_, "b")
 
     def param_encode(self, old_val):
-        val = [ord(c) for c in old_val]
+        if type(old_val) is str:
+            val = bytearray(old_val.encode())
+        else:
+            val = bytearray(old_val)
+
         val.append(0)
         return super().param_encode(val)
 
 
 class PointerWrapper:
-    """ Wrapper for non-const T pointers that retrieves any
+    """Wrapper for non-const T pointers that retrieves any
     data modified by the called function.
 
     """
+
     def __init__(self, type_, struct_string):
-        self._lenstruct = struct.Struct('h')
+        self._lenstruct = struct.Struct("h")
         self._struct_string = struct_string
         self.typedefname = None
         self.blocks = True
@@ -220,7 +214,7 @@ class PointerWrapper:
     def param_decode(self, old_val, stream):
         data = stream.read(self._lenstruct.size)
         length = self._lenstruct.unpack(data)[0]
-        assert(length == len(old_val))
+        assert length == len(old_val)
         data = stream.read(length * struct.calcsize(self._struct_string))
         old_val[:] = struct.unpack(self._struct_string * len(old_val), data)
 
@@ -231,33 +225,33 @@ class PointerWrapper:
         commands = []
         commands.append(
             _generate_decl(
-                name + '_len',
-                c_ast.TypeDecl(name + '_len', [],
-                               c_ast.IdentifierType(['unsigned', 'short']))))
-        commands.append(_generate_read(name + '_len'))
-        commands.append(_generate_arraydecl(name,
-                                            self._type,
-                                            c_ast.ID(name + '_len')))
+                name + "_len",
+                c_ast.TypeDecl(
+                    name + "_len", [], c_ast.IdentifierType(["unsigned", "short"])
+                ),
+            )
+        )
+        commands.append(_generate_read(name + "_len"))
+        commands.append(_generate_arraydecl(name, self._type, c_ast.ID(name + "_len")))
         commands.append(_generate_read(name, address=False))
         return commands
 
     def post_argument(self, name):
         commands = []
-        commands.append(_generate_write(name + '_len'))
+        commands.append(_generate_write(name + "_len"))
         commands.append(_generate_write(name, address=False))
         return commands
 
 
 class VoidWrapper:
-    """ Wraps void - only valid for return types
+    """Wraps void - only valid for return types"""
 
-    """
     def __init__(self):
         self.typedefname = None
         self.blocks = False
 
     def param_encode(self, old_val):
-        return b''
+        return b""
 
     def param_decode(self, old_val, stream):
         pass
@@ -279,37 +273,37 @@ def _type_to_struct_string(tdecl):
     names = tdecl.type.names
     signed = True
     if len(names) > 1:
-        if names[0] == 'unsigned':
+        if names[0] == "unsigned":
             signed = False
         name = names[1]
     else:
         name = names[0]
-    if name == 'void':
-        return ''
-    if name in ['long', 'int']:
-        if names.count('long') == 2:
+    if name == "void":
+        return ""
+    if name in ["long", "int"]:
+        if names.count("long") == 2:
             if signed:
-                return 'q'
+                return "q"
             else:
-                return 'Q'
+                return "Q"
         else:
             if signed:
-                return 'i'
+                return "i"
             else:
-                return 'I'
-    if name == 'short':
+                return "I"
+    if name == "short":
         if signed:
-            return 'h'
+            return "h"
         else:
-            return 'H'
-    if name == 'char':
+            return "H"
+    if name == "char":
         if signed:
-            return 'b'
+            return "b"
         else:
-            return 'B'
-    if name == 'float':
-        return 'f'
-    raise RuntimeError('Unknown type {}'.format(name))
+            return "B"
+    if name == "float":
+        return "f"
+    raise RuntimeError("Unknown type {}".format(name))
 
 
 class MicroblazeError(Exception):
@@ -318,7 +312,7 @@ class MicroblazeError(Exception):
 
 class PyIntWrapper(PrimitiveWrapper):
     def __init__(self, type_):
-        super().__init__('i', type_)
+        super().__init__("i", type_)
 
     def return_decode(self, stream):
         data = stream.read(self._struct.size)
@@ -330,7 +324,7 @@ class PyIntWrapper(PrimitiveWrapper):
 
 class PyVoidWrapper(PrimitiveWrapper):
     def __init__(self, type_):
-        super().__init__('i', type_)
+        super().__init__("i", type_)
 
     def return_decode(self, stream):
         data = stream.read(self._struct.size)
@@ -342,7 +336,7 @@ class PyVoidWrapper(PrimitiveWrapper):
 
 class PyBoolWrapper(PrimitiveWrapper):
     def __init__(self, type_):
-        super().__init__('i', type_)
+        super().__init__("i", type_)
 
     def return_decode(self, stream):
         data = stream.read(self._struct.size)
@@ -354,7 +348,7 @@ class PyBoolWrapper(PrimitiveWrapper):
 
 class PyFloatWrapper(PrimitiveWrapper):
     def __init__(self, type_):
-        super().__init__('f', type_)
+        super().__init__("f", type_)
 
     def return_decode(self, stream):
         data = stream.read(self._struct.size)
@@ -365,17 +359,15 @@ class PyFloatWrapper(PrimitiveWrapper):
 
 
 _interface_overrides = {
-        'py_int': PyIntWrapper,
-        'py_bool': PyBoolWrapper,
-        'py_float': PyFloatWrapper,
-        'py_void': PyVoidWrapper
+    "py_int": PyIntWrapper,
+    "py_bool": PyBoolWrapper,
+    "py_float": PyFloatWrapper,
+    "py_void": PyVoidWrapper,
 }
 
 
 def _type_to_interface(tdecl, typedefs):
-    """ Returns a wrapper for a given C AST
-
-    """
+    """Returns a wrapper for a given C AST"""
 
     if type(tdecl) is c_ast.PtrDecl:
         nested_type = tdecl.type
@@ -383,8 +375,8 @@ def _type_to_interface(tdecl, typedefs):
             raise RuntimeError("Only single level pointers supported")
         struct_string = _type_to_struct_string(nested_type)
         if struct_string:
-            if 'const' in nested_type.quals:
-                if struct_string == 'b':
+            if "const" in nested_type.quals:
+                if struct_string == "b":
                     return ConstCharPointerWrapper(tdecl)
                 else:
                     return ConstPointerWrapper(tdecl, struct_string)
@@ -413,39 +405,34 @@ def _type_to_interface(tdecl, typedefs):
 
 
 def _generate_read(name, size=None, address=True):
-    """ Helper function to generate read functions. size
+    """Helper function to generate read functions. size
     should be an AST fragment
 
     """
     if size is None:
-        size = c_ast.UnaryOp('sizeof', c_ast.ID(name))
+        size = c_ast.UnaryOp("sizeof", c_ast.ID(name))
     if address:
-        target = c_ast.UnaryOp('&', c_ast.ID(name))
+        target = c_ast.UnaryOp("&", c_ast.ID(name))
     else:
         target = c_ast.ID(name)
 
-    return c_ast.FuncCall(
-        c_ast.ID('_rpc_read'),
-        c_ast.ExprList([target,
-                        size]))
+    return c_ast.FuncCall(c_ast.ID("_rpc_read"), c_ast.ExprList([target, size]))
 
 
 def _generate_write(name, address=True):
-    """ Helper function generate write functions
-
-    """
+    """Helper function generate write functions"""
     if address:
-        target = c_ast.UnaryOp('&', c_ast.ID(name))
+        target = c_ast.UnaryOp("&", c_ast.ID(name))
     else:
         target = c_ast.ID(name)
     return c_ast.FuncCall(
-        c_ast.ID('_rpc_write'),
-        c_ast.ExprList([target,
-                        c_ast.UnaryOp('sizeof', c_ast.ID(name))]))
+        c_ast.ID("_rpc_write"),
+        c_ast.ExprList([target, c_ast.UnaryOp("sizeof", c_ast.ID(name))]),
+    )
 
 
 def _generate_decl(name, decl):
-    """ Generates a new declaration with a difference name
+    """Generates a new declaration with a difference name
     but same type as the provided decl.
 
     """
@@ -454,7 +441,7 @@ def _generate_decl(name, decl):
 
 
 def _generate_arraydecl(name, decl, length):
-    """ Generates a new declaration with an array type
+    """Generates a new declaration with an array type
     base on an existing declaration
 
     """
@@ -476,6 +463,7 @@ class FuncAdapter:
         Syntax tree for the wrapped function call
 
     """
+
     def __init__(self, decl, typedefs):
         self.return_interface = _type_to_interface(decl.type, typedefs)
         self.name = decl.type.declname
@@ -495,56 +483,58 @@ class FuncAdapter:
                 interface = _type_to_interface(arg.type, typedefs)
                 if type(interface) is VoidWrapper:
                     continue
-                block_contents.extend(interface.pre_argument('arg' + str(i)))
-                post_block_contents.extend(interface.post_argument(
-                    'arg' + str(i)))
-                func_args.append(c_ast.ID('arg' + str(i)))
+                block_contents.extend(interface.pre_argument("arg" + str(i)))
+                post_block_contents.extend(interface.post_argument("arg" + str(i)))
+                func_args.append(c_ast.ID("arg" + str(i)))
                 self.arg_interfaces.append(interface)
                 self.blocks = self.blocks | interface.blocks
                 if arg.name:
                     self.args.append(arg.name)
                 else:
-                    self.args.append(f'arg{len(self.args)}')
+                    self.args.append(f"arg{len(self.args)}")
 
-        function_call = c_ast.FuncCall(c_ast.ID(self.name),
-                                       c_ast.ExprList(func_args))
+        function_call = c_ast.FuncCall(c_ast.ID(self.name), c_ast.ExprList(func_args))
 
         self.returns = type(self.return_interface) is not VoidWrapper
         if self.returns:
             ret_assign = c_ast.Decl(
-                'ret', [], [], [],
-                c_ast.TypeDecl('ret', [], decl.type.type),
-                function_call, []
+                "ret",
+                [],
+                [],
+                [],
+                c_ast.TypeDecl("ret", [], decl.type.type),
+                function_call,
+                [],
             )
             block_contents.append(ret_assign)
-            block_contents.append(_generate_write('return_command'))
+            block_contents.append(_generate_write("return_command"))
             block_contents.extend(post_block_contents)
-            block_contents.append(_generate_write('ret'))
+            block_contents.append(_generate_write("ret"))
             self.blocks = True
         else:
             block_contents.append(function_call)
             if self.blocks:
-                block_contents.append(_generate_write('return_command'))
+                block_contents.append(_generate_write("return_command"))
             else:
-                block_contents.append(_generate_write('void_command'))
+                block_contents.append(_generate_write("void_command"))
             block_contents.extend(post_block_contents)
 
         self.call_ast = c_ast.Compound(block_contents)
         self.filename = decl.coord.file
 
     def pack_args(self, *args):
-        """Create a bytes of the provided arguments
-
-        """
+        """Create a bytes of the provided arguments"""
         if len(args) != len(self.arg_interfaces):
             raise RuntimeError(
                 "Wrong number of arguments: expected{0} got {1}".format(
                     len(self.arg_interfaces), len(args)
-                ))
-        return b''.join(
-            [f.param_encode(a) for f, a in itertools.zip_longest(
-                self.arg_interfaces, args
-            )]
+                )
+            )
+        return b"".join(
+            [
+                f.param_encode(a)
+                for f, a in itertools.zip_longest(self.arg_interfaces, args)
+            ]
         )
 
     def receive_response(self, stream, *args):
@@ -556,18 +546,19 @@ class FuncAdapter:
             raise RuntimeError(
                 "Wrong number of arguments: expected{0} got {1}".format(
                     len(self.arg_interfaces), len(args)
-                ))
-        [f.param_decode(a, stream) for f, a in itertools.zip_longest(
-             self.arg_interfaces, args
-        )]
+                )
+            )
+        [
+            f.param_decode(a, stream)
+            for f, a in itertools.zip_longest(self.arg_interfaces, args)
+        ]
         return_value = self.return_interface.return_decode(stream)
         return return_value
 
 
 class ParsedEnum:
-    """Holds the values of an enum from the C source
+    """Holds the values of an enum from the C source"""
 
-    """
     def __init__(self):
         self.name = None
         self.file = None
@@ -579,6 +570,7 @@ class FuncDefVisitor(pycparser.c_ast.NodeVisitor):
     typedes and enumerations from a syntax tree
 
     """
+
     def __init__(self):
         self.functions = {}
         self.typedefs = {}
@@ -596,22 +588,21 @@ class FuncDefVisitor(pycparser.c_ast.NodeVisitor):
         self.visit(node.decl)
 
     def visit_FuncDecl(self, node):
-        if node.coord.file.startswith('/opt/microblaze'):
+        if node.coord.file.startswith("/opt/microblaze"):
             return
         if type(node.type) is not c_ast.TypeDecl:
             # Ignore functions that are returning pointers
             return
         name = node.type.declname
-        if 'static' in node.type.quals:
+        if "static" in node.type.quals:
             # Don't process static functions
             return
         try:
             self.functions[name] = FuncAdapter(node, self.typedefs)
             self.function_coords[name] = node.coord
         except RuntimeError as e:
-            if node.coord.file == '<stdin>':
-                print("Could not create interface for funcion {}: {}".format(
-                    name, e))
+            if node.coord.file == "<stdin>":
+                print("Could not create interface for funcion {}: {}".format(name, e))
 
     def visit_Enum(self, node):
         enum = ParsedEnum()
@@ -628,60 +619,54 @@ class FuncDefVisitor(pycparser.c_ast.NodeVisitor):
 
 
 def _build_case(functions):
-    """ Builds the switch statement that will form the foundation
+    """Builds the switch statement that will form the foundation
     of the RPC handler
 
     """
     cases = []
     for i, func in enumerate(functions.values()):
-        case = c_ast.Case(
-            c_ast.Constant('int', str(i)),
-            [
-                func.call_ast,
-                c_ast.Break()
-            ])
+        case = c_ast.Case(c_ast.Constant("int", str(i)), [func.call_ast, c_ast.Break()])
         cases.append(case)
-    return c_ast.Switch(
-        c_ast.ID('command'),
-        c_ast.Compound(cases)
-    )
+    return c_ast.Switch(c_ast.ID("command"), c_ast.Compound(cases))
 
 
 def _build_handle_function(functions):
-    """ Wraps the switch statement in a function definition
-
-    """
+    """Wraps the switch statement in a function definition"""
     case_statement = _build_case(functions)
     available_check = c_ast.If(
         c_ast.BinaryOp(
-            '<', c_ast.FuncCall(
-                c_ast.ID('mailbox_available'),
-                c_ast.ExprList([c_ast.Constant('int', '2')])
+            "<",
+            c_ast.FuncCall(
+                c_ast.ID("mailbox_available"),
+                c_ast.ExprList([c_ast.Constant("int", "2")]),
             ),
-            c_ast.Constant('int', '4')
+            c_ast.Constant("int", "4"),
         ),
         c_ast.Return(None),
-        None
+        None,
     )
     handle_decl = c_ast.FuncDecl(
-        None, c_ast.TypeDecl('_handle_events', [],
-                             c_ast.IdentifierType(['void'])),
+        None,
+        c_ast.TypeDecl("_handle_events", [], c_ast.IdentifierType(["void"])),
     )
-    command_decl = c_ast.Decl('command', [], [], [],
-                              c_ast.TypeDecl('command', [],
-                                             c_ast.IdentifierType(['int'])),
-                              [], [])
-    command_read = _generate_read('command')
-    body = c_ast.Compound([available_check,
-                           command_decl,
-                           command_read,
-                           case_statement])
+    command_decl = c_ast.Decl(
+        "command",
+        [],
+        [],
+        [],
+        c_ast.TypeDecl("command", [], c_ast.IdentifierType(["int"])),
+        [],
+        [],
+    )
+    command_read = _generate_read("command")
+    body = c_ast.Compound([available_check, command_decl, command_read, case_statement])
     return c_ast.FuncDef(handle_decl, [], body)
 
 
 def _build_main(program_text, functions):
     sections = []
-    sections.append(R"""
+    sections.append(
+        R"""
     extern "C" {
     #include <unistd.h>
     #include <mailbox_io.h>
@@ -704,18 +689,21 @@ def _build_main(program_text, functions):
         }
         mailbox_write(3, data, size);
     }
-    """)
+    """
+    )
 
     sections.append(program_text)
     sections.append(_generator.visit(_build_handle_function(functions)))
 
-    sections.append(R"""
+    sections.append(
+        R"""
     int main() {
         while (1) {
             _handle_events();
         }
     }
-    """)
+    """
+    )
 
     return "\n".join(sections)
 
@@ -726,22 +714,22 @@ def _pyprintf(stream):
     args = []
     for i in range(len(format_string)):
         if in_special:
-            if format_string[i:i+1] in [b'd']:
+            if format_string[i : i + 1] in [b"d"]:
                 args.append(stream.read_int32())
-            elif format_string[i:i+1] in [b'x', b'X', b'o', b'u']:
+            elif format_string[i : i + 1] in [b"x", b"X", b"o", b"u"]:
                 # perform unsigned conversion
                 args.append(stream.read_uint32())
-            elif format_string[i:i+1] in [b'f', b'F', b'g', b'G', b'e', b'E']:
+            elif format_string[i : i + 1] in [b"f", b"F", b"g", b"G", b"e", b"E"]:
                 args.append(stream.read_float())
-            elif format_string[i:i+1] == b's':
+            elif format_string[i : i + 1] == b"s":
                 args.append(stream.read_string().decode())
-            elif format_string[i:i+1] == b'c':
+            elif format_string[i : i + 1] == b"c":
                 args.append(stream.read_byte())
             in_special = False
-        elif format_string[i:i+1] == b'%':
+        elif format_string[i : i + 1] == b"%":
             in_special = True
 
-    print(format_string.decode() % tuple(args), end='')
+    print(format_string.decode() % tuple(args), end="")
 
 
 def _handle_command(command, stream):
@@ -750,15 +738,15 @@ def _handle_command(command, stream):
     elif command == 2:  # print command
         _pyprintf(stream)
     else:
-        raise RuntimeError('Unknown command {}'.format(command))
+        raise RuntimeError("Unknown command {}".format(command))
 
 
 def _function_wrapper(stream, index, adapter, return_type, *args):
-    """ Calls a function in the microblaze, designed to be used
+    """Calls a function in the microblaze, designed to be used
     with functools.partial to build a new thing
 
     """
-    arg_string = struct.pack('i', index)
+    arg_string = struct.pack("i", index)
     arg_string += adapter.pack_args(*args)
     stream.write(arg_string)
     if not adapter.returns:
@@ -775,11 +763,10 @@ def _function_wrapper(stream, index, adapter, return_type, *args):
 
 
 def _create_typedef_classes(typedefs, typedef_coords):
-    """ Creates an anonymous class for each typedef in the C function
-
-    """
+    """Creates an anonymous class for each typedef in the C function"""
     classes = {}
     for k, v in typedefs.items():
+
         class Wrapper:
             """Wrapper class for a C typedef
 
@@ -789,6 +776,7 @@ def _create_typedef_classes(typedefs, typedef_coords):
             otherwise it is added as a static method.
 
             """
+
             def __init__(self, val):
                 self._val = val
 
@@ -802,8 +790,10 @@ def _create_typedef_classes(typedefs, typedef_coords):
                 return function(self._val, *args)
 
             def __repr__(self):
-                return "typedef {0} containing {1}".format(type(self).__name__,
-                                                           repr(self._val))
+                return "typedef {0} containing {1}".format(
+                    type(self).__name__, repr(self._val)
+                )
+
             _file = typedef_coords[k].file
 
         Wrapper.__name__ = k
@@ -832,25 +822,25 @@ def _get_docstring(coord):
     # We need to subtract 2 as coord is 1-indexed
     keyline = lines[coord.line - 2].rstrip()
     comment_lines = collections.deque()
-    if keyline.startswith('// '):
+    if keyline.startswith("// "):
         i = coord.line - 2
-        while i >= 0 and lines[i].startswith('// '):
+        while i >= 0 and lines[i].startswith("// "):
             comment_lines.appendleft(lines[i][3:].rstrip())
             i -= 1
-    elif keyline.endswith('*/'):
+    elif keyline.endswith("*/"):
         i = coord.line - 2
         # Strip comment close
-        line = re.sub(r'\W*\*+/\W*', '', lines[i])
+        line = re.sub(r"\W*\*+/\W*", "", lines[i])
         if line:
             comment_lines.appendleft(line.rstrip())
         i -= 1
         # Add Intermediate lines
-        while i >= 0 and not lines[i].startswith('/*'):
+        while i >= 0 and not lines[i].startswith("/*"):
             line = lines[i].rstrip()
-            line = re.sub(r' \* ?', '', line)
+            line = re.sub(r" \* ?", "", line)
             comment_lines.appendleft(line)
             i -= 1
-        line = re.sub(r'/\*+\W*', '', lines[i].rstrip())
+        line = re.sub(r"/\*+\W*", "", lines[i].rstrip())
         if line:
             comment_lines.appendleft(line)
 
@@ -858,10 +848,10 @@ def _get_docstring(coord):
         return None
     return "\n".join(comment_lines)
 
-class MicroblazeFunction:
-    """Calls a specific function
 
-    """
+class MicroblazeFunction:
+    """Calls a specific function"""
+
     def __init__(self, stream, index, function, return_type):
         self.stream = stream
         self.index = index
@@ -869,7 +859,7 @@ class MicroblazeFunction:
         self.return_type = return_type
 
     def _call_function(self, *args):
-        arg_string = struct.pack('i', self.index)
+        arg_string = struct.pack("i", self.index)
         arg_string += self.function.pack_args(*args)
         self.stream.write(arg_string)
 
@@ -915,6 +905,7 @@ class MicroblazeFunction:
         else:
             return return_value
 
+
 def _create_function_class(function):
     call_func = f"""def call(self, {', '.join(function.args)}):
         {repr(function.docstring)}
@@ -922,9 +913,11 @@ def _create_function_class(function):
     """
     scope = {}
     exec(call_func, scope)
-    derived = type("MicroblazeFuncion_"+function.name,
-                   (MicroblazeFunction,),
-                   {'__call__': scope['call'], '__doc__': function.docstring})
+    derived = type(
+        "MicroblazeFuncion_" + function.name,
+        (MicroblazeFunction,),
+        {"__call__": scope["call"], "__doc__": function.docstring},
+    )
     return derived
 
 
@@ -934,14 +927,14 @@ def _create_instance_function(function):
         {repr(function.__doc__)}
         return self._call_func(function, {', '.join(args[1:])})
     """
-    scope = {'function': function}
+    scope = {"function": function}
     exec(func_string, scope)
-    wrapped = scope['wrapped']
+    wrapped = scope["wrapped"]
     return wrapped
 
 
 class MicroblazeRPC:
-    """ Provides a python interface to the Microblaze based on an RPC
+    """Provides a python interface to the Microblaze based on an RPC
     mechanism.
 
     The attributes of the class are generated dynamically from the
@@ -951,8 +944,9 @@ class MicroblazeRPC:
     added as constants to the class and types are added as classes.
 
     """
+
     def __init__(self, iop, program_text):
-        """ Create a new RPC instance
+        """Create a new RPC instance
 
         Parameters
         ----------
@@ -964,19 +958,20 @@ class MicroblazeRPC:
         """
         preprocessed = preprocess(program_text, mb_info=iop)
         try:
-            ast = _parser.parse(preprocessed, filename='program_text')
+            ast = _parser.parse(preprocessed, filename="program_text")
         except ParseError as e:
             raise RuntimeError("Error parsing code\n" + str(e))
         visitor = FuncDefVisitor()
         visitor.visit(ast)
         main_text = _build_main(program_text, visitor.functions)
-        used_typedefs = _filter_typedefs(visitor.typedefs,
-                                         visitor.functions.keys())
-        typedef_classes = _create_typedef_classes(visitor.typedefs,
-                                                  visitor.typedef_coords)
+        used_typedefs = _filter_typedefs(visitor.typedefs, visitor.functions.keys())
+        typedef_classes = _create_typedef_classes(
+            visitor.typedefs, visitor.typedef_coords
+        )
         self._mb = MicroblazeProgram(iop, main_text)
         self._rpc_stream = InterruptMBStream(
-            self._mb, read_offset=0xFC00, write_offset=0xF800)
+            self._mb, read_offset=0xFC00, write_offset=0xF800
+        )
         self._build_functions(visitor.functions, typedef_classes)
         self._build_constants(visitor.enums, typedef_classes)
         self._populate_typedefs(typedef_classes, visitor.functions)
@@ -1001,39 +996,38 @@ class MicroblazeRPC:
             if v.return_interface.typedefname:
                 return_type = typedef_classes[v.return_interface.typedefname]
             FunctionType = _create_function_class(v)
-            setattr(self, k,
-                    FunctionType(
-                        self._rpc_stream,
-                        index, v, return_type)
-                    )
+            setattr(self, k, FunctionType(self._rpc_stream, index, v, return_type))
             index += 1
 
     def _populate_typedefs(self, typedef_classes, functions):
         for name, cls in typedef_classes.items():
             for fname, func in functions.items():
                 if fname.startswith(name + "_"):
-                    subname = fname[len(name)+1:]
-                    if (len(func.arg_interfaces) > 0 and
-                            func.arg_interfaces[0].typedefname == name):
-                        setattr(cls, subname,
-                                _create_instance_function(getattr(self, fname)))
-            getters = [s for s in dir(cls) if s.startswith('get_')]
+                    subname = fname[len(name) + 1 :]
+                    if (
+                        len(func.arg_interfaces) > 0
+                        and func.arg_interfaces[0].typedefname == name
+                    ):
+                        setattr(
+                            cls,
+                            subname,
+                            _create_instance_function(getattr(self, fname)),
+                        )
+            getters = [s for s in dir(cls) if s.startswith("get_")]
             for g in getters:
-                p = g[4:] # Strip the get_ off the front for the name
-                setattr(cls, p,
-                        property(getattr(cls, "get_" + p),
-                                 getattr(cls, "set_" + p, None)))
+                p = g[4:]  # Strip the get_ off the front for the name
+                setattr(
+                    cls,
+                    p,
+                    property(getattr(cls, "get_" + p), getattr(cls, "set_" + p, None)),
+                )
 
     def reset(self):
-        """Reset and free the microblaze for use by other programs
-
-        """
+        """Reset and free the microblaze for use by other programs"""
         self._mb.reset()
 
     def release(self):
-        """Alias for `reset()`
-
-        """
+        """Alias for `reset()`"""
         self.reset()
 
 
@@ -1046,6 +1040,7 @@ class MicroblazeLibrary(MicroblazeRPC):
 
 
     """
+
     def __init__(self, iop, libraries):
         """Create a Python API for a list of C libraries
 
@@ -1060,6 +1055,7 @@ class MicroblazeLibrary(MicroblazeRPC):
              List of the names of the libraries to load
 
         """
-        source_text = "\n".join(['#include <{}.h>'.format(lib)
-                                 for lib in libraries])
+        source_text = "\n".join(["#include <{}.h>".format(lib) for lib in libraries])
         super().__init__(iop, source_text)
+
+
