@@ -1,31 +1,5 @@
-#   Copyright (c) 2019, Xilinx, Inc.
-#   All rights reserved.
-#
-#   Redistribution and use in source and binary forms, with or without
-#   modification, are permitted provided that the following conditions are met:
-#
-#   1.  Redistributions of source code must retain the above copyright notice,
-#       this list of conditions and the following disclaimer.
-#
-#   2.  Redistributions in binary form must reproduce the above copyright
-#       notice, this list of conditions and the following disclaimer in the
-#       documentation and/or other materials provided with the distribution.
-#
-#   3.  Neither the name of the copyright holder nor the names of its
-#       contributors may be used to endorse or promote products derived from
-#       this software without specific prior written permission.
-#
-#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-#   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-#   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-#   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
-#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-#   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-#   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
-#   OR BUSINESS INTERRUPTION). HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-#   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-#   OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-#   ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#   Copyright (c) 2021, Xilinx, Inc.
+#   SPDX-License-Identifier: BSD-3-Clause
 
 import functools
 import textwrap
@@ -33,9 +7,6 @@ import numpy as np
 import re
 import warnings
 
-__author__ = "Peter Ogden, Yun Rock Qu"
-__copyright__ = "Copyright 2019, Xilinx"
-__email__ = "pynq_support@xilinx.com"
 
 
 def _wrap_docstring(doc):
@@ -120,7 +91,8 @@ class Register:
 
     """
 
-    def __init__(self, address, width=32, debug=False, buffer=None):
+    def __init__(self, address, width=32, debug=False, buffer=None,
+                 access='read-write', device=None):
         """Instantiate a register object.
 
         Parameters
@@ -141,6 +113,7 @@ class Register:
         self.address = address
         self.width = width
         self.debug = debug
+        self.access = access
 
         if width == 32:
             register_type = 'u4'
@@ -151,7 +124,8 @@ class Register:
 
         if buffer is None:
             from .mmio import MMIO
-            array = MMIO(address, np.dtype(register_type).itemsize).array
+            mmio = MMIO(address, np.dtype(register_type).itemsize, device=device)
+            array = mmio.array
         elif hasattr(buffer, 'view'):
             array = buffer
         else:
@@ -172,6 +146,8 @@ class Register:
         """
         lower, upper, reverse = _calc_index(index, self.width)
         curr_val = int(self._buffer[0])
+        if self.access == 'write-only':
+            return self.access
         if lower == upper:
             self._debug("Reading index {} at address {}"
                         .format(index, hex(self.address)))
@@ -268,9 +244,14 @@ class Register:
         """
         if hasattr(self, '_fields') and self._fields:
             field_desc = []
-            for k in self._fields.keys():
-                field_desc.append("{}={}".format(k, getattr(self, k)))
+            for k, v in self._fields.items():
+                if v['access'] != 'write-only':
+                    field_desc.append("{}={}".format(k, getattr(self, k)))
+                else:
+                    field_desc.append("{}={}".format(k, 'write-only'))
             return "Register({})".format(", ".join(field_desc))
+        elif self.access == 'write-only':
+            return "Register(value={})".format(self.access)
         else:
             return "Register(value={})".format(self[:])
 
@@ -313,7 +294,7 @@ class Register:
         for k, v in fields.items():
             attrname = _safe_attrname(k)
             safe_fields[attrname] = v
-            doc = _wrap_docstring(v['description'])
+            doc = _wrap_docstring(v.get('description', ''))
             stop = v['bit_offset']
             start = stop + v['bit_width'] - 1
             index = slice(start, stop, -1)
@@ -324,8 +305,8 @@ class Register:
             else:
                 attr_dict[attrname] = property(
                     functools.partial(Register.__getitem__, index=index),
-                    functools.partial(Register._reordered_setitem, index=index),
-                    doc=doc)
+                    functools.partial(Register._reordered_setitem,
+                                      index=index), doc=doc)
         return type("Register" + name, (Register,), attr_dict)
 
     @classmethod
@@ -371,12 +352,10 @@ class RegisterMap:
                                "create_subclass can be instantiated")
         if hasattr(buffer, 'view'):
             array32 = buffer.view(dtype='u4')
-            array64 = buffer.view(dtype='u8')
         else:
             array32 = np.frombuffer(buffer=buffer, dtype=np.uint32,
                                     count=self._map_size // 4)
-            array64 = np.frombuffer(buffer=buffer, dtype=np.uint64,
-                                    count=self._map_size // 8)
+
         self._instances = {}
         for k, v in self._register_classes.items():
             if v[2] <= 32:
@@ -393,8 +372,9 @@ class RegisterMap:
                         v[2], k
                     ))
                 continue
+
             self._instances[k] = v[0](
-                address=v[1], width=align_width, buffer=array)
+                address=v[1], width=align_width, buffer=array, access=v[5])
 
     def _set_value(self, value, name):
         self._instances[name][:] = value
@@ -404,9 +384,9 @@ class RegisterMap:
 
     def __repr__(self):
         register_info = []
-        for k, v in sorted(self._instances.items(), key=lambda x: x[1].address):
-            register_info.append(
-                "  {} = {}".format(k, repr(v)))
+        for k, v in \
+                sorted(self._instances.items(), key=lambda x: x[1].address):
+            register_info.append("  {} = {}".format(k, repr(v)))
         return "RegisterMap {\n" + ",\n".join(register_info) + "\n}"
 
     @classmethod
@@ -439,14 +419,15 @@ class RegisterMap:
         name = _safe_attrname(name)
         for k, v in registers.items():
             attrname = _safe_attrname(k)
-            doc = _wrap_docstring(v['description'])
+            doc = _wrap_docstring(v.get('description', ''))
             if 'fields' in v:
                 register_class = Register.create_subclass(
                         attrname, v['fields'], doc)
             else:
                 register_class = Register
             register_classes[attrname] = (
-                register_class, v['address_offset'], v['size'])
+                register_class, v['address_offset'], v['size'],
+                None, None, v['access'])
             upper_range = v['address_offset'] + v['size'] // 8
             if upper_range > address_high:
                 address_high = upper_range
@@ -464,3 +445,5 @@ class RegisterMap:
         attr_dict['_register_classes'] = register_classes
         attr_dict['_map_size'] = address_high
         return type("RegisterMap" + name, (RegisterMap,), attr_dict)
+
+
